@@ -102,15 +102,10 @@ public:  // methods
     /// within a DistFDB (i.e. within one Rendezvous hash).
     virtual std::string id() const;
 
-    virtual FDBStats stats() const;
-
     const std::string& name() const;
 
     const Config& config() const;
 
-    void disable();
-    bool disabled();
-
     bool enabled(const ControlIdentifier& controlIdentifier) const;
 
 private:  // methods
@@ -129,8 +124,6 @@ protected:  // members
     Config config_;
 
     ControlIdentifiers controlIdentifiers_;
-
-    bool disabled_;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
