@@ -62,6 +62,22 @@ std::map<std::string, eckit::Regex> parseFDBSelect(const eckit::LocalConfigurati
     return selectDict;
 }
 
+SelectFDB::FDBLane::FDBLane(const eckit::LocalConfiguration& config) :
+    select_(parseFDBSelect(config)), config_(config), fdb_(std::nullopt) {}
+
+
+FDB& SelectFDB::FDBLane::get() {
+    if (!fdb_) {
+        fdb_.emplace(config_);
+    }
+    return *fdb_;
+}
+
+void SelectFDB::FDBLane::flush() {
+    if (fdb_) {
+        fdb_->flush();
+    }
+}
 
 SelectFDB::SelectFDB(const Config& config, const std::string& name) : FDBBase(config, name) {
 
@@ -72,7 +88,7 @@ SelectFDB::SelectFDB(const Config& config, const std::string& name) : FDBBase(co
     }
 
     for (const auto& c : config.getSubConfigs("fdbs")) {
-        subFdbs_.emplace_back(std::make_pair(parseFDBSelect(c), FDB(c)));
+        subFdbs_.emplace_back(FDBLane{c});
     }
 }
 
@@ -81,13 +97,9 @@ SelectFDB::~SelectFDB() {}
 
 void SelectFDB::archive(const Key& key, const void* data, size_t length) {
 
-    for (auto& iter : subFdbs_) {
-
-        const SelectMap& select(iter.first);
-        FDB& fdb(iter.second);
-
-        if (matches(key, select, true)) {
-            fdb.archive(key, data, length);
+    for (auto& lane : subFdbs_) {
+        if (matches(key, lane.select(), true)) {
+            lane.get().archive(key, data, length);
             return;
         }
     }
@@ -101,14 +113,10 @@ ListIterator SelectFDB::inspect(const metkit::mars::MarsRequest& request) {
 
     std::queue<APIIterator<ListElement>> lists;
 
-    for (auto& iter : subFdbs_) {
-
-        const SelectMap& select(iter.first);
-        FDB& fdb(iter.second);
-
+    for (auto& lane : subFdbs_) {
         // If we want to allow non-fully-specified retrieves, make false here.
-        if (matches(request, select, true)) {
-            lists.push(fdb.inspect(request));
+        if (matches(request, lane.select(), true)) {
+            lists.push(lane.get().inspect(request));
         }
     }
 
@@ -124,13 +132,9 @@ auto SelectFDB::queryInternal(const FDBToolRequest& request, const QueryFN& fn)
 
     std::queue<APIIterator<ValueType>> iterQueue;
 
-    for (auto& iter : subFdbs_) {
-
-        const SelectMap& select(iter.first);
-        FDB& fdb(iter.second);
-
-        if (matches(request.request(), select, false) || request.all()) {
-            iterQueue.push(fn(fdb, request));
+    for (auto& lane : subFdbs_) {
+        if (request.all() || matches(request.request(), lane.select(), false)) {
+            iterQueue.push(fn(lane.get(), request));
         }
     }
 
@@ -188,9 +192,8 @@ AxesIterator SelectFDB::axesIterator(const FDBToolRequest& request, int level) {
 }
 
 void SelectFDB::flush() {
-    for (auto& iter : subFdbs_) {
-        FDB& fdb(iter.second);
-        fdb.flush();
+    for (auto& lane : subFdbs_) {
+        lane.flush();
     }
 }
 
@@ -200,15 +203,19 @@ void SelectFDB::print(std::ostream& s) const {
 }
 
 bool SelectFDB::matches(const Key& key, const SelectMap& select, bool requireMissing) const {
+
     for (const auto& [keyword, regex] : select) {
         const auto [iter, found] = key.find(keyword);
 
-        if (!found && requireMissing) {
-            return false;
+        if (!found) {
+            if (requireMissing) {
+                return false;
+            }
         }
-
-        if (!regex.match(iter->second)) {
-            return false;
+        else {
+            if (!regex.match(iter->second)) {
+                return false;
+            }
         }
     }
     return true;
@@ -216,22 +223,18 @@ bool SelectFDB::matches(const Key& key, const SelectMap& select, bool requireMis
 
 bool SelectFDB::matches(const metkit::mars::MarsRequest& request, const SelectMap& select, bool requireMissing) const {
 
-    for (const auto& kv : select) {
+    for (const auto& [keyword, regex] : select) {
 
-        const std::string& k(kv.first);
-        const eckit::Regex& re(kv.second);
-
-        const std::vector<std::string>& request_values = request.values(k, /* emptyOK */ true);
+        const std::vector<std::string>& request_values = request.values(keyword, /* emptyOK */ true);
 
         if (request_values.size() == 0) {
             if (requireMissing)
                 return false;
         }
         else {
-
             bool re_match = false;
             for (const std::string& v : request_values) {
-                if (re.match(v)) {
+                if (regex.match(v)) {
                     re_match = true;
                     break;
                 }
