@@ -16,10 +16,10 @@
 /// @author Simon Smart
 /// @date   Mar 2018
 
-#ifndef fdb5_api_SelectFDB_H
-#define fdb5_api_SelectFDB_H
+#pragma once
 
 #include <map>
+#include <optional>
 #include <string>
 #include <vector>
 
@@ -38,6 +38,19 @@ private:  // types
 
     using SelectMap = std::map<std::string, eckit::Regex>;
 
+    class FDBLane {
+        SelectMap select_;
+        Config config_;
+        std::optional<FDB> fdb_;
+
+    public:
+
+        FDBLane(const eckit::LocalConfiguration& config);
+        const SelectMap& select() { return select_; }
+        FDB& get();
+        void flush();
+    };
+
 public:  // methods
 
     SelectFDB(const Config& config, const std::string& name);
@@ -81,11 +94,9 @@ private:  // methods
 
 private:  // members
 
-    std::vector<std::pair<SelectMap, FDB>> subFdbs_;
+    std::vector<FDBLane> subFdbs_;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
 }  // namespace fdb5
-
-#endif  // fdb5_api_SelectFDB_H
