@@ -54,31 +54,13 @@ public:
     ListIterator(APIIterator<ListElement>&& iter, bool deduplicate = false) :
         APIIterator<ListElement>(std::move(iter)), seenKeys_({}), deduplicate_(deduplicate) {}
 
-    ListIterator(ListIterator&& iter) :
-        APIIterator<ListElement>(std::move(iter)),
-        seenKeys_(std::move(iter.seenKeys_)),
-        deduplicate_(iter.deduplicate_) {}
+    ListIterator(ListIterator&& iter) = default;
 
-    ListIterator& operator=(ListIterator&& iter) {
-        seenKeys_    = std::move(iter.seenKeys_);
-        deduplicate_ = iter.deduplicate_;
-        APIIterator<ListElement>::operator=(std::move(iter));
-        return *this;
-    }
+    ListIterator& operator=(ListIterator&& iter) = default;
 
-    bool next(ListElement& elem) {
-        ListElement tmp;
-        while (APIIterator<ListElement>::next(tmp)) {
-            if (deduplicate_) {
-                if (const auto [iter, success] = seenKeys_.emplace(tmp.combinedKey()); !success) {
-                    continue;
-                }
-            }
-            std::swap(elem, tmp);
-            return true;
-        }
-        return false;
-    }
+    bool next(ListElement& elem);
+
+    std::pair<size_t, eckit::Length> dumpCompact(std::ostream& out);
 
 private:
 
