@@ -19,6 +19,9 @@
 #ifndef fdb5_api_local_QueryVisitor_H
 #define fdb5_api_local_QueryVisitor_H
 
+#include <tuple>
+#include <unordered_map>
+
 #include "fdb5/database/EntryVisitMechanism.h"
 #include "fdb5/rules/Rule.h"
 
@@ -26,9 +29,7 @@
 
 #include "metkit/mars/MarsRequest.h"
 
-namespace fdb5 {
-namespace api {
-namespace local {
+namespace fdb5::api::local {
 
 /// @note Helper classes for LocalFDB
 
@@ -48,29 +49,29 @@ protected:  // methods
 
     const metkit::mars::MarsRequest& canonicalise(const Rule& rule) const {
         bool success;
-        auto it = canonicalised_.find(&rule);
+        auto it = canonicalised_.find(&rule.registry());
         if (it == canonicalised_.end()) {
-            std::tie(it, success) = canonicalised_.emplace(&rule, rule.registry().canonicalise(request_));
+            std::tie(it, success) = canonicalised_.emplace(&rule.registry(), rule.registry().canonicalise(request_));
             ASSERT(success);
         }
         return it->second;
     }
-        
+
+
 protected:  // members
 
     eckit::Queue<ValueType>& queue_;
     metkit::mars::MarsRequest request_;
 
-private:    // members
+private:  // members
 
-    mutable std::map<const Rule*, metkit::mars::MarsRequest> canonicalised_;
+    /// Cache of canonicalised requests
+    mutable std::unordered_map<const TypesRegistry*, metkit::mars::MarsRequest> canonicalised_;
 };
 
 
 //----------------------------------------------------------------------------------------------------------------------
 
-}  // namespace local
-}  // namespace api
-}  // namespace fdb5
+}  // namespace fdb5::api::local
 
 #endif
