@@ -10,11 +10,11 @@
 
 #include "fdb5/LibFdb5.h"
 
-#include "fdb5/daos/DaosSession.h"
 #include "fdb5/daos/DaosName.h"
+#include "fdb5/daos/DaosSession.h"
 
-#include "fdb5/daos/DaosIndex.h"
 #include "fdb5/daos/DaosCatalogueReader.h"
+#include "fdb5/daos/DaosIndex.h"
 
 namespace fdb5 {
 
@@ -23,12 +23,10 @@ namespace fdb5 {
 /// @note: as opposed to the TOC catalogue, the DAOS catalogue does not pre-load all indexes from storage.
 ///   Instead, it selects and loads only those indexes that are required to fulfil the request.
 
-DaosCatalogueReader::DaosCatalogueReader(const Key& dbKey, const fdb5::Config& config) :
-    DaosCatalogue(dbKey, config) {
+DaosCatalogueReader::DaosCatalogueReader(const Key& dbKey, const fdb5::Config& config) : DaosCatalogue(dbKey, config) {
 
     /// @todo: schema is being loaded at DaosCatalogueWriter creation for write, but being loaded
     ///        at DaosCatalogueReader::open for read. Is this OK?
-
 }
 
 DaosCatalogueReader::DaosCatalogueReader(const eckit::URI& uri, const fdb5::Config& config) :
@@ -55,7 +53,7 @@ bool DaosCatalogueReader::selectIndex(const Key& idxKey) {
         fdb5::DaosKeyValue catalogue_kv_obj{s, catalogue_kv};
 
         int idx_loc_max_len = 512;  /// @todo: take from config
-        std::vector<char> n((long) idx_loc_max_len);
+        std::vector<char> n((long)idx_loc_max_len);
         long res;
 
         try {
@@ -63,14 +61,13 @@ bool DaosCatalogueReader::selectIndex(const Key& idxKey) {
             /// @note: performed RPCs:
             /// - retrieve index kv location from catalogue kv (daos_kv_get)
             res = catalogue_kv_obj.get(idxKey.valuesToString(), &n[0], idx_loc_max_len);
-
-        } catch (fdb5::DaosEntityNotFoundException& e) {
+        }
+        catch (fdb5::DaosEntityNotFoundException& e) {
 
             /// @note: performed RPCs:
             /// - close catalogue kv (daos_obj_close)
 
             return false;
-
         }
 
         fdb5::DaosKeyValueName index_kv{eckit::URI{std::string{n.begin(), std::next(n.begin(), res)}}};
@@ -79,19 +76,16 @@ bool DaosCatalogueReader::selectIndex(const Key& idxKey) {
 
         /// @note: performed RPCs:
         /// - close catalogue kv (daos_obj_close)
-
     }
 
     current_ = indexes_[idxKey];
 
     return true;
-
 }
 
 void DaosCatalogueReader::deselectIndex() {
 
-    NOTIMP; //< should not be called
-    
+    NOTIMP;  //< should not be called
 }
 
 bool DaosCatalogueReader::open() {
@@ -107,19 +101,17 @@ bool DaosCatalogueReader::open() {
 
     DaosCatalogue::loadSchema();
     return true;
-
 }
 
 bool DaosCatalogueReader::axis(const std::string& keyword, eckit::DenseSet<std::string>& s) const {
 
     bool found = false;
     if (current_.axes().has(keyword)) {
-        found = true;
+        found                                 = true;
         const eckit::DenseSet<std::string>& a = current_.axes().values(keyword);
         s.merge(a);
     }
     return found;
-
 }
 
 bool DaosCatalogueReader::retrieve(const Key& key, Field& field) const {
@@ -127,14 +119,14 @@ bool DaosCatalogueReader::retrieve(const Key& key, Field& field) const {
     eckit::Log::debug<LibFdb5>() << "Trying to retrieve key " << key << std::endl;
     eckit::Log::debug<LibFdb5>() << "Scanning index " << current_.location() << std::endl;
 
-    if (!current_.mayContain(key)) return false;
+    if (!current_.mayContain(key))
+        return false;
 
     return current_.get(key, fdb5::Key(), field);
-
 }
 
 static fdb5::CatalogueReaderBuilder<fdb5::DaosCatalogueReader> builder("daos");
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
