@@ -31,10 +31,9 @@ std::shared_ptr<const FieldLocation> DaosLazyFieldLocation::make_shared() const
 eckit::DataHandle* DaosLazyFieldLocation::dataHandle() const {
 
     return realise()->dataHandle();
-    
 }
 
-void DaosLazyFieldLocation::print(std::ostream &out) const {
+void DaosLazyFieldLocation::print(std::ostream& out) const {
     out << *realise();
 }
 
@@ -48,7 +47,8 @@ std::shared_ptr<const FieldLocation> DaosLazyFieldLocation::stableLocation() con
 
 std::unique_ptr<fdb5::FieldLocation>& DaosLazyFieldLocation::realise() const {
 
-    if (fl_) return fl_;
+    if (fl_)
+        return fl_;
 
     /// @note: performed RPCs:
     /// - index kv get (daos_kv_get)
@@ -64,7 +64,6 @@ std::unique_ptr<fdb5::FieldLocation>& DaosLazyFieldLocation::realise() const {
     fl_.reset(eckit::Reanimator<fdb5::FieldLocation>::reanimate(ms));
 
     return fl_;
-
 }
 
-} // namespace fdb5
+}  // namespace fdb5
