@@ -10,14 +10,14 @@
 
 #include "eckit/config/Resource.h"
 
-#include "fdb5/daos/DaosFieldLocation.h"
-#include "fdb5/daos/DaosStore.h"
 #include "fdb5/daos/DaosArrayHandle.h"
-#include "fdb5/daos/DaosObject.h"
 #include "fdb5/daos/DaosContainer.h"
+#include "fdb5/daos/DaosException.h"
+#include "fdb5/daos/DaosFieldLocation.h"
+#include "fdb5/daos/DaosObject.h"
 #include "fdb5/daos/DaosPool.h"
 #include "fdb5/daos/DaosSession.h"
-#include "fdb5/daos/DaosException.h"
+#include "fdb5/daos/DaosStore.h"
 
 namespace fdb5 {
 
@@ -29,17 +29,13 @@ DaosStore::DaosStore(const Key& key, const Config& config) :
 eckit::URI DaosStore::uri() const {
 
     return fdb5::DaosName(pool_, db_str_).URI();
-    
 }
 
 bool DaosStore::uriBelongs(const eckit::URI& uri) const {
 
     /// @todo: avoid building a DaosName as it makes uriBelongs expensive
     /// @todo: assert uri points to a (not necessarily existing) array object
-    return (
-        (uri.scheme() == type()) && 
-        (fdb5::DaosName(uri).containerName().rfind(db_str_, 0) == 0));
-
+    return ((uri.scheme() == type()) && (fdb5::DaosName(uri).containerName().rfind(db_str_, 0) == 0));
 }
 
 bool DaosStore::uriExists(const eckit::URI& uri) const {
@@ -54,7 +50,6 @@ bool DaosStore::uriExists(const eckit::URI& uri) const {
     ASSERT(n.hasOID());
 
     return n.exists();
-
 }
 
 std::vector<eckit::URI> DaosStore::collocatedDataURIs() const {
@@ -62,47 +57,44 @@ std::vector<eckit::URI> DaosStore::collocatedDataURIs() const {
     std::vector<eckit::URI> collocated_data_uris;
 
     fdb5::DaosName db_cont{pool_, db_str_};
-    
-    if (!db_cont.exists()) return collocated_data_uris;
-    
+
+    if (!db_cont.exists())
+        return collocated_data_uris;
+
     for (const auto& oid : db_cont.listOIDs()) {
-        
+
         if (oid.otype() != DAOS_OT_KV_HASHED && oid.otype() != DAOS_OT_ARRAY_BYTE)
             throw eckit::SeriousBug("Found non-KV non-ByteArray objects in DB container " + db_cont.URI().asString());
-        
-        if (oid.otype() == DAOS_OT_KV_HASHED) continue;
+
+        if (oid.otype() == DAOS_OT_KV_HASHED)
+            continue;
 
         collocated_data_uris.push_back(fdb5::DaosArrayName(pool_, db_str_, oid).URI());
-
     }
 
     return collocated_data_uris;
-
 }
 
 std::set<eckit::URI> DaosStore::asCollocatedDataURIs(const std::vector<eckit::URI>& uris) const {
 
     std::set<eckit::URI> res;
 
-    for (auto& uri : uris) 
+    for (auto& uri : uris)
         /// @note: seems redundant, but intends to check validity of input URIs
         res.insert(fdb5::DaosName(uri).URI());
 
     return res;
-
 }
 
 bool DaosStore::exists() const {
 
     return fdb5::DaosName(pool_).exists();
-
 }
 
 /// @todo: never used in actual fdb-read?
 eckit::DataHandle* DaosStore::retrieve(Field& field) const {
 
     return field.dataHandle();
-
 }
 
 std::unique_ptr<const FieldLocation> DaosStore::archive(const Key&, const void* data, eckit::Length length) {
@@ -110,10 +102,12 @@ std::unique_ptr<const FieldLocation> DaosStore::archive(const Key&, const void*
     /// @note: performed RPCs:
     /// - open pool if not cached (daos_pool_connect) -- always skipped as it is cached after selectDatabase.
     ///   If the cat backend is toc, then it is performed but only on first write.
-    /// - check if container exists if not cached (daos_cont_open) -- always skipped as it is cached after selectDatabase.
+    /// - check if container exists if not cached (daos_cont_open) -- always skipped as it is cached after
+    /// selectDatabase.
     ///   If the cat backend is toc, then it is performed but only on first write.
     /// - allocate oid (daos_cont_alloc_oids) -- skipped most of the times as oids per alloc is set to 100
-    fdb5::DaosArrayName n = fdb5::DaosName(pool_, db_str_).createArrayName(OC_S1, false); // TODO: pass oclass from config
+    fdb5::DaosArrayName n =
+        fdb5::DaosName(pool_, db_str_).createArrayName(OC_S1, false);  // TODO: pass oclass from config
 
     std::unique_ptr<eckit::DataHandle> h(n.dataHandle());
 
@@ -149,7 +143,7 @@ size_t DaosStore::flush() {
 void DaosStore::remove(const eckit::URI& uri, std::ostream& logAlways, std::ostream& logVerbose, bool doit) const {
 
     fdb5::DaosName n{uri};
-    
+
     ASSERT(n.hasContainerName());
     ASSERT(n.poolName() == pool_);
     ASSERT(n.containerName() == db_str_);
@@ -157,23 +151,23 @@ void DaosStore::remove(const eckit::URI& uri, std::ostream& logAlways, std::ostr
     if (n.hasOID()) {
         ASSERT(n.OID().otype() == DAOS_OT_ARRAY_BYTE);
         logVerbose << "destroy array: ";
-    } else {
+    }
+    else {
         logVerbose << "destroy container: ";
     }
 
     logAlways << n.asString() << std::endl;
-    if (doit) n.destroy();
-
+    if (doit)
+        n.destroy();
 }
 
-void DaosStore::print(std::ostream &out) const {
+void DaosStore::print(std::ostream& out) const {
 
     out << "DaosStore(" << pool_ << ")";
-
 }
 
 static StoreBuilder<DaosStore> builder("daos");
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
