@@ -47,19 +47,20 @@ typedef std::map<Key, Index> IndexStore;
 
 class Catalogue {
 public:
-    Catalogue() = default;
+
+    Catalogue()          = default;
     virtual ~Catalogue() = default;
 
-    virtual const Key& key() const = 0;
-    virtual const Key& indexKey() const = 0;
+    virtual const Key& key() const       = 0;
+    virtual const Key& indexKey() const  = 0;
     virtual const Config& config() const = 0;
 
     virtual std::unique_ptr<Store> buildStore() const = 0;
-    virtual const Schema& schema() const = 0;
-    virtual const Rule& rule() const = 0;
+    virtual const Schema& schema() const              = 0;
+    virtual const Rule& rule() const                  = 0;
 
     virtual bool selectIndex(const Key& idxKey) = 0;
-    virtual void deselectIndex() = 0;
+    virtual void deselectIndex()                = 0;
 
     virtual std::vector<eckit::PathName> metadataPaths() const = 0;
 
@@ -67,18 +68,21 @@ public:
 
     virtual void hideContents() = 0;
 
-    virtual void dump(std::ostream& out, bool simple=false, const eckit::Configuration& conf = eckit::LocalConfiguration()) const = 0;
+    virtual void dump(std::ostream& out, bool simple = false,
+                      const eckit::Configuration& conf = eckit::LocalConfiguration()) const = 0;
 
-    virtual StatsReportVisitor* statsReportVisitor() const = 0;
-    virtual PurgeVisitor* purgeVisitor(const Store& store) const = 0;
-    virtual WipeVisitor* wipeVisitor(const Store& store, const metkit::mars::MarsRequest& request, std::ostream& out, bool doit, bool porcelain, bool unsafeWipeAll) const = 0;
-    virtual MoveVisitor* moveVisitor(const Store& store, const metkit::mars::MarsRequest& request, const eckit::URI& dest, eckit::Queue<MoveElement>& queue) const = 0;
+    virtual StatsReportVisitor* statsReportVisitor() const                                           = 0;
+    virtual PurgeVisitor* purgeVisitor(const Store& store) const                                     = 0;
+    virtual WipeVisitor* wipeVisitor(const Store& store, const metkit::mars::MarsRequest& request, std::ostream& out,
+                                     bool doit, bool porcelain, bool unsafeWipeAll) const            = 0;
+    virtual MoveVisitor* moveVisitor(const Store& store, const metkit::mars::MarsRequest& request,
+                                     const eckit::URI& dest, eckit::Queue<MoveElement>& queue) const = 0;
 
     virtual void control(const ControlAction& action, const ControlIdentifiers& identifiers) const = 0;
 
     virtual bool enabled(const ControlIdentifier& controlIdentifier) const = 0;
 
-    virtual std::vector<fdb5::Index> indexes(bool sorted=false) const = 0;
+    virtual std::vector<fdb5::Index> indexes(bool sorted = false) const = 0;
 
     /// For use by the WipeVisitor
     virtual void maskIndexEntry(const Index& index) const = 0;
@@ -87,31 +91,30 @@ public:
     virtual void allMasked(std::set<std::pair<eckit::URI, eckit::Offset>>& metadata,
                            std::set<eckit::URI>& data) const = 0;
 
-    friend std::ostream &operator<<(std::ostream &s, const Catalogue &x);
-    virtual void print( std::ostream &out ) const = 0;
+    friend std::ostream& operator<<(std::ostream& s, const Catalogue& x);
+    virtual void print(std::ostream& out) const = 0;
 
-    virtual std::string type() const = 0;
-    virtual bool open() = 0;
+    virtual std::string type() const          = 0;
+    virtual bool open()                       = 0;
     virtual void flush(size_t archivedFields) = 0;
-    virtual void clean() = 0;
-    virtual void close() = 0;
+    virtual void clean()                      = 0;
+    virtual void close()                      = 0;
 
-    virtual bool exists() const = 0;
+    virtual bool exists() const   = 0;
     virtual void checkUID() const = 0;
 
     virtual eckit::URI uri() const = 0;
 
-protected: // methods
+protected:  // methods
 
     virtual void loadSchema() = 0;
-
 };
 
 class CatalogueImpl : virtual public Catalogue {
 public:
 
-    CatalogueImpl(const Key& key, ControlIdentifiers controlIdentifiers, const fdb5::Config& config)
-        : dbKey_(key), config_(config), controlIdentifiers_(controlIdentifiers) {}
+    CatalogueImpl(const Key& key, ControlIdentifiers controlIdentifiers, const fdb5::Config& config) :
+        dbKey_(key), config_(config), controlIdentifiers_(controlIdentifiers) {}
 
     ~CatalogueImpl() override {}
 
@@ -125,21 +128,21 @@ public:
 
     bool enabled(const ControlIdentifier& controlIdentifier) const override;
 
-protected: // methods
+protected:  // methods
 
     CatalogueImpl() : dbKey_(Key()), config_(Config()), controlIdentifiers_(ControlIdentifiers()) {}
 
-protected: // members
+protected:  // members
 
     Key dbKey_;
     Config config_;
     ControlIdentifiers controlIdentifiers_;
-
 };
 
 class CatalogueReader : virtual public Catalogue {
 
 public:
+
     ~CatalogueReader() override {}
 
     virtual DbStats stats() const = 0;
@@ -149,17 +152,21 @@ public:
 };
 
 
-class CatalogueWriter : virtual public Catalogue  {
+class CatalogueWriter : virtual public Catalogue {
 
 public:
+
     ~CatalogueWriter() override {}
 
     virtual const Index& currentIndex() = 0;
     virtual const Key currentIndexKey();
-    virtual void archive(const Key& idxKey, const Key& datumKey, std::shared_ptr<const FieldLocation> fieldLocation) = 0;
-    virtual void overlayDB(const Catalogue& otherCatalogue, const std::set<std::string>& variableKeys, bool unmount) = 0;
+    virtual void archive(const Key& idxKey, const Key& datumKey,
+                         std::shared_ptr<const FieldLocation> fieldLocation)                              = 0;
+    virtual void overlayDB(const Catalogue& otherCatalogue, const std::set<std::string>& variableKeys,
+                           bool unmount)                                                                  = 0;
     virtual void index(const Key& key, const eckit::URI& uri, eckit::Offset offset, eckit::Length length) = 0;
-    virtual void reconsolidate() = 0;
+    virtual void reconsolidate()                                                                          = 0;
+    virtual size_t archivedLocations() const { NOTIMP; }
 };
 
 //----------------------------------------------------------------------------------------------------------------------
@@ -168,24 +175,31 @@ class CatalogueReaderBuilderBase {
     std::string name_;
 
 public:
+
     CatalogueReaderBuilderBase(const std::string&);
     virtual ~CatalogueReaderBuilderBase();
-    virtual std::unique_ptr<CatalogueReader> make(const fdb5::Key& key, const fdb5::Config& config) = 0;
+    virtual std::unique_ptr<CatalogueReader> make(const fdb5::Key& key, const fdb5::Config& config)  = 0;
     virtual std::unique_ptr<CatalogueReader> make(const eckit::URI& uri, const fdb5::Config& config) = 0;
 };
 
 template <class T>
 class CatalogueReaderBuilder : public CatalogueReaderBuilderBase {
-    virtual std::unique_ptr<CatalogueReader> make(const fdb5::Key& key, const fdb5::Config& config) override { return std::unique_ptr<T>(new T(key, config)); }
-    virtual std::unique_ptr<CatalogueReader> make(const eckit::URI& uri, const fdb5::Config& config) override { return std::unique_ptr<T>(new T(uri, config)); }
+    virtual std::unique_ptr<CatalogueReader> make(const fdb5::Key& key, const fdb5::Config& config) override {
+        return std::unique_ptr<T>(new T(key, config));
+    }
+    virtual std::unique_ptr<CatalogueReader> make(const eckit::URI& uri, const fdb5::Config& config) override {
+        return std::unique_ptr<T>(new T(uri, config));
+    }
 
 public:
+
     CatalogueReaderBuilder(const std::string& name) : CatalogueReaderBuilderBase(name) {}
     virtual ~CatalogueReaderBuilder() = default;
 };
 
 class CatalogueReaderFactory {
 public:
+
     static CatalogueReaderFactory& instance();
 
     void add(const std::string& name, CatalogueReaderBuilderBase* builder);
@@ -200,6 +214,7 @@ public:
     std::unique_ptr<CatalogueReader> build(const eckit::URI& uri, const Config& config);
 
 private:
+
     CatalogueReaderFactory();
 
     std::map<std::string, CatalogueReaderBuilderBase*> builders_;
@@ -212,24 +227,31 @@ class CatalogueWriterBuilderBase {
     std::string name_;
 
 public:
+
     CatalogueWriterBuilderBase(const std::string&);
     virtual ~CatalogueWriterBuilderBase();
-    virtual std::unique_ptr<CatalogueWriter> make(const fdb5::Key& key, const fdb5::Config& config) = 0;
+    virtual std::unique_ptr<CatalogueWriter> make(const fdb5::Key& key, const fdb5::Config& config)  = 0;
     virtual std::unique_ptr<CatalogueWriter> make(const eckit::URI& uri, const fdb5::Config& config) = 0;
 };
 
 template <class T>
 class CatalogueWriterBuilder : public CatalogueWriterBuilderBase {
-    virtual std::unique_ptr<CatalogueWriter> make(const fdb5::Key& key, const fdb5::Config& config) override { return std::unique_ptr<T>(new T(key, config)); }
-    virtual std::unique_ptr<CatalogueWriter> make(const eckit::URI& uri, const fdb5::Config& config) override { return std::unique_ptr<T>(new T(uri, config)); }
+    virtual std::unique_ptr<CatalogueWriter> make(const fdb5::Key& key, const fdb5::Config& config) override {
+        return std::unique_ptr<T>(new T(key, config));
+    }
+    virtual std::unique_ptr<CatalogueWriter> make(const eckit::URI& uri, const fdb5::Config& config) override {
+        return std::unique_ptr<T>(new T(uri, config));
+    }
 
 public:
+
     CatalogueWriterBuilder(const std::string& name) : CatalogueWriterBuilderBase(name) {}
     virtual ~CatalogueWriterBuilder() = default;
 };
 
 class CatalogueWriterFactory {
 public:
+
     static CatalogueWriterFactory& instance();
 
     void add(const std::string& name, CatalogueWriterBuilderBase* builder);
@@ -244,6 +266,7 @@ public:
     std::unique_ptr<CatalogueWriter> build(const eckit::URI& uri, const Config& config);
 
 private:
+
     CatalogueWriterFactory();
 
     std::map<std::string, CatalogueWriterBuilderBase*> builders_;
@@ -261,7 +284,7 @@ public:
 
     const Schema& schema() const override { NOTIMP; }
     const Rule& rule() const override { NOTIMP; }
-    
+
     bool selectIndex(const Key& idxKey) override { NOTIMP; }
     void deselectIndex() override { NOTIMP; }
 
@@ -269,27 +292,38 @@ public:
 
     void hideContents() override { NOTIMP; }
 
-    void dump(std::ostream& out, bool simple=false, const eckit::Configuration& conf = eckit::LocalConfiguration()) const override { NOTIMP; }
+    void dump(std::ostream& out, bool simple = false,
+              const eckit::Configuration& conf = eckit::LocalConfiguration()) const override {
+        NOTIMP;
+    }
     bool enabled(const ControlIdentifier& controlIdentifier) const override { NOTIMP; }
 
     StatsReportVisitor* statsReportVisitor() const override { NOTIMP; }
     PurgeVisitor* purgeVisitor(const Store& store) const override { NOTIMP; }
-    WipeVisitor* wipeVisitor(const Store& store, const metkit::mars::MarsRequest& request, std::ostream& out, bool doit, bool porcelain, bool unsafeWipeAll) const override { NOTIMP; }
-    MoveVisitor* moveVisitor(const Store& store, const metkit::mars::MarsRequest& request, const eckit::URI& dest, eckit::Queue<MoveElement>& queue) const override { NOTIMP; }
+    WipeVisitor* wipeVisitor(const Store& store, const metkit::mars::MarsRequest& request, std::ostream& out, bool doit,
+                             bool porcelain, bool unsafeWipeAll) const override {
+        NOTIMP;
+    }
+    MoveVisitor* moveVisitor(const Store& store, const metkit::mars::MarsRequest& request, const eckit::URI& dest,
+                             eckit::Queue<MoveElement>& queue) const override {
+        NOTIMP;
+    }
 
     void control(const ControlAction& action, const ControlIdentifiers& identifiers) const override { NOTIMP; }
 
-    std::vector<fdb5::Index> indexes(bool sorted=false) const override { NOTIMP; }
+    std::vector<fdb5::Index> indexes(bool sorted = false) const override { NOTIMP; }
 
     /// For use by the WipeVisitor
     void maskIndexEntry(const Index& index) const override { NOTIMP; }
 
     /// For use by purge/wipe
     void allMasked(std::set<std::pair<eckit::URI, eckit::Offset>>& metadata,
-                           std::set<eckit::URI>& data) const override { NOTIMP; }
+                   std::set<eckit::URI>& data) const override {
+        NOTIMP;
+    }
 
-    friend std::ostream &operator<<(std::ostream &s, const Catalogue &x);
-    void print( std::ostream &out ) const override { NOTIMP; }
+    friend std::ostream& operator<<(std::ostream& s, const Catalogue& x);
+    void print(std::ostream& out) const override { NOTIMP; }
 
     std::string type() const override { NOTIMP; }
     bool open() override { NOTIMP; }
@@ -302,10 +336,9 @@ public:
 
     eckit::URI uri() const override { NOTIMP; }
 
-protected: // methods
+protected:  // methods
 
     void loadSchema() override { NOTIMP; }
-
 };
 
-}
+}  // namespace fdb5
