@@ -15,18 +15,13 @@ namespace fdb5 {
 //----------------------------------------------------------------------------------------------------------------------
 
 void FieldDetails::print(std::ostream& out) const {
-    out
-    << "(referenceValue=" <<       referenceValue_
-    << ",binaryScaleFactor=" <<    binaryScaleFactor_
-    << ",decimalScaleFactor=" <<   decimalScaleFactor_
-    << ",bitsPerValue=" <<         bitsPerValue_
-    << ",offsetBeforeData=" <<     offsetBeforeData_
-    << ",offsetBeforeBitmap=" <<   offsetBeforeBitmap_
-    << ",numberOfValues=" <<       numberOfValues_
-    << ",numberOfDataPoints=" <<   numberOfDataPoints_
-    << ",sphericalHarmonics=" <<   sphericalHarmonics_ << ")";
+    out << "(referenceValue=" << referenceValue_ << ",binaryScaleFactor=" << binaryScaleFactor_
+        << ",decimalScaleFactor=" << decimalScaleFactor_ << ",bitsPerValue=" << bitsPerValue_
+        << ",offsetBeforeData=" << offsetBeforeData_ << ",offsetBeforeBitmap=" << offsetBeforeBitmap_
+        << ",numberOfValues=" << numberOfValues_ << ",numberOfDataPoints=" << numberOfDataPoints_
+        << ",sphericalHarmonics=" << sphericalHarmonics_ << ")";
 }
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
