@@ -18,10 +18,12 @@
 
 namespace fdb5 {
 
-::eckit::ClassSpec FieldLocation::classSpec_ = {&Streamable::classSpec(), "FieldLocation",};
+::eckit::ClassSpec FieldLocation::classSpec_ = {
+    &Streamable::classSpec(),
+    "FieldLocation",
+};
 
-FieldLocationFactory::FieldLocationFactory() {
-}
+FieldLocationFactory::FieldLocationFactory() {}
 
 FieldLocationFactory& FieldLocationFactory::instance() {
     static FieldLocationFactory theOne;
@@ -30,7 +32,7 @@ FieldLocationFactory& FieldLocationFactory::instance() {
 
 void FieldLocationFactory::add(const std::string& name, FieldLocationBuilderBase* builder) {
     eckit::AutoLock<eckit::Mutex> lock(mutex_);
-    if(has(name)) {
+    if (has(name)) {
         throw eckit::SeriousBug("Duplicate entry in FieldLocationFactory: " + name, Here());
     }
     builders_[name] = builder;
@@ -48,15 +50,17 @@ bool FieldLocationFactory::has(const std::string& name) {
 void FieldLocationFactory::list(std::ostream& out) {
     eckit::AutoLock<eckit::Mutex> lock(mutex_);
     const char* sep = "";
-    for (std::map<std::string, FieldLocationBuilderBase*>::const_iterator j = builders_.begin(); j != builders_.end(); ++j) {
+    for (std::map<std::string, FieldLocationBuilderBase*>::const_iterator j = builders_.begin(); j != builders_.end();
+         ++j) {
         out << sep << (*j).first;
         sep = ", ";
     }
 }
 
-FieldLocation* FieldLocationFactory::build(const std::string& name, const eckit::URI &uri, eckit::Offset offset, eckit::Length length, const Key& remapKey) {
+FieldLocation* FieldLocationFactory::build(const std::string& name, const eckit::URI& uri, eckit::Offset offset,
+                                           eckit::Length length, const Key& remapKey) {
 
-    ASSERT (length != 0);
+    ASSERT(length != 0);
 
     eckit::AutoLock<eckit::Mutex> lock(mutex_);
 
@@ -75,7 +79,7 @@ FieldLocation* FieldLocationFactory::build(const std::string& name, const eckit:
     return (*j).second->make(uri, offset, length, remapKey);
 }
 
-FieldLocation* FieldLocationFactory::build(const std::string& name, const eckit::URI &uri) {
+FieldLocation* FieldLocationFactory::build(const std::string& name, const eckit::URI& uri) {
 
     eckit::AutoLock<eckit::Mutex> lock(mutex_);
 
@@ -101,7 +105,8 @@ FieldLocationBuilderBase::FieldLocationBuilderBase(const std::string& name) : na
 }
 
 FieldLocationBuilderBase::~FieldLocationBuilderBase() {
-    if(LibFdb5::instance().dontDeregisterFactories()) return;
+    if (LibFdb5::instance().dontDeregisterFactories())
+        return;
     FieldLocationFactory::instance().remove(name_);
 }
 
@@ -110,7 +115,8 @@ FieldLocationBuilderBase::~FieldLocationBuilderBase() {
 FieldLocation::FieldLocation(const eckit::URI& uri) : uri_(uri) {
     try {
         offset_ = eckit::Offset(std::stoll(uri.fragment()));
-    } catch (std::invalid_argument& e) {
+    }
+    catch (std::invalid_argument& e) {
         offset_ = eckit::Offset(0);
     }
 
@@ -118,17 +124,20 @@ FieldLocation::FieldLocation(const eckit::URI& uri) : uri_(uri) {
     if (!lengthStr.empty()) {
         try {
             length_ = eckit::Length(std::stoll(lengthStr));
-        }  catch (std::invalid_argument& e) {
+        }
+        catch (std::invalid_argument& e) {
             length_ = eckit::Length(0);
         }
-    } else {
+    }
+    else {
         length_ = eckit::Length(0);
     }
 
     const std::string keyStr = uri.query("remapKey");
     if (!keyStr.empty()) {
         remapKey_ = Key::parse(keyStr);
-    } else {
+    }
+    else {
         remapKey_ = Key();
     }
 }
@@ -144,8 +153,8 @@ eckit::URI FieldLocation::fullUri() const {
 }
 
 
-FieldLocation::FieldLocation(const eckit::URI& uri, eckit::Offset offset, eckit::Length length, const Key& remapKey)
-    : uri_(uri), offset_(offset), length_(length), remapKey_(remapKey) {}
+FieldLocation::FieldLocation(const eckit::URI& uri, eckit::Offset offset, eckit::Length length, const Key& remapKey) :
+    uri_(uri), offset_(offset), length_(length), remapKey_(remapKey) {}
 
 void FieldLocation::encode(eckit::Stream& s) const {
     s << uri_;
@@ -161,21 +170,21 @@ FieldLocation::FieldLocation(eckit::Stream& s) {
     s >> remapKey_;
 }
 
-//void FieldLocation::remapKey(const Key& key) { NOTIMP; }
-//const Key& FieldLocation::remapKey() const { NOTIMP; }
+// void FieldLocation::remapKey(const Key& key) { NOTIMP; }
+// const Key& FieldLocation::remapKey() const { NOTIMP; }
 
 void FieldLocation::dump(std::ostream& out) const {
     out << "  uri: " << uri().asRawString();
 }
 
 void FieldLocation::print(std::ostream& out) const {
-    out << "  FieldLocation[uri=" << uri_ << ",offset=" << offset() << ",length=" << length() << ",remapKey=" << remapKey_ << "]";
+    out << "  FieldLocation[uri=" << uri_ << ",offset=" << offset() << ",length=" << length()
+        << ",remapKey=" << remapKey_ << "]";
 }
 
 //----------------------------------------------------------------------------------------------------------------------
 
-FieldLocationVisitor::~FieldLocationVisitor()
-{}
+FieldLocationVisitor::~FieldLocationVisitor() {}
 
 void FieldLocationPrinter::operator()(const FieldLocation& location) {
     location.dump(out_);
@@ -183,4 +192,4 @@ void FieldLocationPrinter::operator()(const FieldLocation& location) {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
