@@ -13,17 +13,17 @@
 
 #include <fstream>
 
-#include "eckit/log/Log.h"
-#include "eckit/utils/Regex.h"
 #include "eckit/config/Resource.h"
+#include "eckit/log/Log.h"
+#include "eckit/thread/AutoLock.h"
+#include "eckit/thread/Mutex.h"
+#include "eckit/utils/Regex.h"
 #include "eckit/utils/Tokenizer.h"
 #include "eckit/utils/Translator.h"
-#include "eckit/thread/Mutex.h"
-#include "eckit/thread/AutoLock.h"
 
 #include "fdb5/LibFdb5.h"
-#include "fdb5/database/Key.h"
 #include "fdb5/database/Engine.h"
+#include "fdb5/database/Key.h"
 #include "fdb5/rules/Schema.h"
 
 
@@ -35,14 +35,11 @@ namespace fdb5 {
 
 struct EngineType {
 
-    EngineType(const std::string& name, const std::string& re) :
-        name_(name),
-        re_(re) {
-    }
+    EngineType(const std::string& name, const std::string& re) : name_(name), re_(re) {}
 
     const std::string& engine() const { return name_; }
 
-    bool match(const std::string& s) const {  return re_.match(s); }
+    bool match(const std::string& s) const { return re_.match(s); }
 
     std::string name_;
     eckit::Regex re_;
@@ -73,7 +70,7 @@ static const EngineTable& readEngineTypes(const eckit::PathName enginesFile) {
 
     // Sensible defaults if not configured
 
-    if(!enginesFile.exists()) {
+    if (!enginesFile.exists()) {
         LOG_DEBUG_LIB(LibFdb5) << "FDB Engines file not found: assuming Engine 'toc' Regex '.*'" << std::endl;
         table.push_back(EngineType("toc", ".*"));
         return table;
@@ -102,7 +99,8 @@ static const EngineTable& readEngineTypes(const eckit::PathName enginesFile) {
         while (i < s.size()) {
             if (s[i].length() == 0) {
                 s.erase(s.begin() + i);
-            } else {
+            }
+            else {
                 i++;
             }
         }
@@ -120,10 +118,9 @@ static const EngineTable& readEngineTypes(const eckit::PathName enginesFile) {
                 break;
             }
 
-        default:
-            eckit::Log::warning() << "FDB Manager: Invalid line ignored: " << line << std::endl;
-            break;
-
+            default:
+                eckit::Log::warning() << "FDB Manager: Invalid line ignored: " << line << std::endl;
+                break;
         }
     }
 
@@ -132,10 +129,10 @@ static const EngineTable& readEngineTypes(const eckit::PathName enginesFile) {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-Manager::Manager(const Config& config) :
-    config_(config) {
+Manager::Manager(const Config& config) : config_(config) {
 
-    static std::string baseEnginesFile = eckit::Resource<std::string>("fdbEnginesFile;$FDB_ENGINES_FILE", "~fdb/etc/fdb/engines");
+    static std::string baseEnginesFile =
+        eckit::Resource<std::string>("fdbEnginesFile;$FDB_ENGINES_FILE", "~fdb/etc/fdb/engines");
 
     enginesFile_ = config.expandPath(baseEnginesFile);
 
@@ -145,10 +142,10 @@ Manager::Manager(const Config& config) :
 Manager::~Manager() {}
 
 
-std::string Manager::engine(const Key& key)
-{
+std::string Manager::engine(const Key& key) {
     // If we have set the engine in the config, use that
-    if (!explicitEngine_.empty()) return explicitEngine_;
+    if (!explicitEngine_.empty())
+        return explicitEngine_;
 
     std::string expanded(key.valuesToString());
 
@@ -156,8 +153,8 @@ std::string Manager::engine(const Key& key)
 
     const EngineTable& engineTypes(readEngineTypes(enginesFile_));
 
-    for (EngineTable::const_iterator i = engineTypes.begin(); i != engineTypes.end() ; ++i) {
-        if(i->match(expanded)) {
+    for (EngineTable::const_iterator i = engineTypes.begin(); i != engineTypes.end(); ++i) {
+        if (i->match(expanded)) {
             const std::string& engine = i->engine();
             if (EngineRegistry::has(engine)) {
                 return engine;
@@ -174,29 +171,29 @@ std::string Manager::engine(const Key& key)
     throw eckit::SeriousBug(oss.str());
 }
 
-std::set<std::string> Manager::engines(const Key& key)
-{
+std::set<std::string> Manager::engines(const Key& key) {
     std::set<std::string> s;
     std::string expanded;
 
     if (!explicitEngine_.empty()) {
         expanded = explicitEngine_;
         s.insert(explicitEngine_);
-    } else {
+    }
+    else {
 
         // Determine matching engine types from the engines file
 
         expanded = key.valuesToString();
         const EngineTable& engineTypes(readEngineTypes(enginesFile_));
 
-        for (EngineTable::const_iterator i = engineTypes.begin(); i != engineTypes.end() ; ++i) {
-            if(key.empty() || i->match(expanded)) {
+        for (EngineTable::const_iterator i = engineTypes.begin(); i != engineTypes.end(); ++i) {
+            if (key.empty() || i->match(expanded)) {
                 s.insert(i->engine());
             }
         }
     }
 
-    if(s.empty()) {
+    if (s.empty()) {
         std::ostringstream oss;
         oss << "No FDB Engine type found for " << key << " (" << expanded << ")";
         throw eckit::SeriousBug(oss.str());
@@ -205,40 +202,43 @@ std::set<std::string> Manager::engines(const Key& key)
     return s;
 }
 
-std::set<std::string> Manager::engines(const metkit::mars::MarsRequest& rq, bool all)
-{
+std::set<std::string> Manager::engines(const metkit::mars::MarsRequest& rq, bool all) {
     std::set<std::string> s;
     std::string expanded;
 
     if (!explicitEngine_.empty()) {
         expanded = explicitEngine_;
         s.insert(explicitEngine_);
-    } else {
+    }
+    else {
 
         const EngineTable& engineTypes(readEngineTypes(enginesFile_));
 
         if (all) {
-            for (auto e = engineTypes.begin(); e != engineTypes.end(); ++e) s.insert(e->engine());
-        } else {
+            for (auto e = engineTypes.begin(); e != engineTypes.end(); ++e)
+                s.insert(e->engine());
+        }
+        else {
 
             // Match all possible expansions of the first level according to the schema
             std::map<Key, const Rule*> keys;
             config_.schema().matchDatabase(rq, keys, "");
 
             std::set<std::string> expandedKeys;
-            for (const auto& [k,r] : keys) {
+            for (const auto& [k, r] : keys) {
                 expandedKeys.insert(k.valuesToString());
             }
 
             for (auto e = engineTypes.begin(); e != engineTypes.end(); ++e) {
                 for (auto expanded = expandedKeys.begin(); expanded != expandedKeys.end(); ++expanded) {
-                    if (e->match(*expanded)) s.insert(e->engine());
+                    if (e->match(*expanded))
+                        s.insert(e->engine());
                 }
             }
         }
     }
 
-    if(s.empty()) {
+    if (s.empty()) {
         std::ostringstream oss;
         oss << "No FDB Engine type found for " << rq << " (" << expanded << ")";
         throw eckit::SeriousBug(oss.str(), Here());
@@ -247,19 +247,19 @@ std::set<std::string> Manager::engines(const metkit::mars::MarsRequest& rq, bool
     return s;
 }
 
-std::string Manager::engine(const URI& uri)
-{
+std::string Manager::engine(const URI& uri) {
     // If we have set the engine in the config, use that
-    if (!explicitEngine_.empty()) return explicitEngine_;
+    if (!explicitEngine_.empty())
+        return explicitEngine_;
 
     // Otherwise, check which engines can handle the given path.
 
     std::vector<Engine*> engines = EngineRegistry::engines();
 
-    for(std::vector<Engine*>::const_iterator i = engines.begin(); i != engines.end(); ++i) {
+    for (std::vector<Engine*>::const_iterator i = engines.begin(); i != engines.end(); ++i) {
         ASSERT(*i);
         const Engine& e = **i;
-        if(e.canHandle(uri, config_)) {
+        if (e.canHandle(uri, config_)) {
             return e.dbType();
         }
     }
@@ -273,16 +273,18 @@ std::vector<eckit::URI> Manager::visitableLocations(const metkit::mars::MarsRequ
 
     std::set<std::string> engines = Manager::engines(rq, all);
 
-    LOG_DEBUG_LIB(LibFdb5) << "Matching engines for request " << rq << (all ? " ALL" : "") << " -> " << engines << std::endl;
+    LOG_DEBUG_LIB(LibFdb5) << "Matching engines for request " << rq << (all ? " ALL" : "") << " -> " << engines
+                           << std::endl;
 
-    std::vector<URI> r; // union of all locations
+    std::vector<URI> r;  // union of all locations
 
-    for(std::set<std::string>::const_iterator i = engines.begin(); i != engines.end(); ++i) {
+    for (std::set<std::string>::const_iterator i = engines.begin(); i != engines.end(); ++i) {
         LOG_DEBUG_LIB(LibFdb5) << "Selected FDB engine " << *i << std::endl;
         std::vector<URI> p;
         if (all) {
             p = Engine::backend(*i).visitableLocations(Key(), config_);
-        } else {
+        }
+        else {
             p = Engine::backend(*i).visitableLocations(rq, config_);
         }
 
@@ -290,7 +292,6 @@ std::vector<eckit::URI> Manager::visitableLocations(const metkit::mars::MarsRequ
     }
 
     return r;
-
 }
 
 //----------------------------------------------------------------------------------------------------------------------
