@@ -20,21 +20,19 @@
 #include "fdb5/types/TypesRegistry.h"
 
 
-
 namespace fdb5 {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-RetrieveVisitor::RetrieveVisitor(const Notifier &wind, HandleGatherer &gatherer) :
-    store_(nullptr), wind_(wind), gatherer_(gatherer) {
-}
+RetrieveVisitor::RetrieveVisitor(const Notifier& wind, HandleGatherer& gatherer) :
+    store_(nullptr), wind_(wind), gatherer_(gatherer) {}
 
 // From Visitor
 
 bool RetrieveVisitor::selectDatabase(const Key& dbKey, const Key& /*fullKey*/) {
 
-    if(catalogue_) {
-        if(dbKey == catalogue_->key()) {
+    if (catalogue_) {
+        if (dbKey == catalogue_->key()) {
             return true;
         }
     }
@@ -80,10 +78,8 @@ bool RetrieveVisitor::selectDatum(const Key& datumKey, const Key& /*fullKey*/) {
     return (dh != 0);
 }
 
-void RetrieveVisitor::values(const metkit::mars::MarsRequest &request,
-                             const std::string &keyword,
-                             const TypesRegistry &registry,
-                             eckit::StringList &values) {
+void RetrieveVisitor::values(const metkit::mars::MarsRequest& request, const std::string& keyword,
+                             const TypesRegistry& registry, eckit::StringList& values) {
     eckit::StringList list;
     registry.lookupType(keyword).getValues(request, keyword, list, wind_, catalogue_);
 
@@ -93,7 +89,7 @@ void RetrieveVisitor::values(const metkit::mars::MarsRequest &request,
         toFilter = catalogue_->axis(keyword, filter);
     }
 
-    for(const auto& value: list) {
+    for (const auto& value : list) {
         std::string v = registry.lookupType(keyword).toKey(value);
         if (!toFilter || filter.find(v) != filter.end()) {
             values.push_back(value);
@@ -110,7 +106,7 @@ Store& RetrieveVisitor::store() {
     return *store_;
 }
 
-void RetrieveVisitor::print( std::ostream &out ) const {
+void RetrieveVisitor::print(std::ostream& out) const {
     out << "RetrieveVisitor[]";
 }
 
@@ -121,4 +117,4 @@ const Schema& RetrieveVisitor::databaseSchema() const {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
