@@ -37,31 +37,37 @@ public:
     virtual ~Store() = default;
 
     virtual eckit::DataHandle* retrieve(Field& field) const = 0;
-    virtual void archive(const Key& idxKey, const void* data, eckit::Length length, std::function<void(const std::unique_ptr<const FieldLocation> fieldLocation)> catalogue_archive);
+    virtual void archive(
+        const Key& idxKey, const void* data, eckit::Length length,
+        std::function<void(const std::unique_ptr<const FieldLocation> fieldLocation)> catalogue_archive);
     virtual std::unique_ptr<const FieldLocation> archive(const Key& idxKey, const void* data, eckit::Length length);
 
-    virtual void remove(const eckit::URI& uri, std::ostream& logAlways, std::ostream& logVerbose, bool doit = true) const = 0;
+    virtual void remove(const eckit::URI& uri, std::ostream& logAlways, std::ostream& logVerbose,
+                        bool doit = true) const = 0;
 
-    friend std::ostream &operator<<(std::ostream &s, const Store &x);
-    virtual void print( std::ostream &out ) const = 0;
+    friend std::ostream& operator<<(std::ostream& s, const Store& x);
+    virtual void print(std::ostream& out) const = 0;
 
     virtual std::string type() const = 0;
-    virtual bool open() = 0;
-    virtual size_t flush() = 0;
-    virtual void close() = 0;
+    virtual bool open()              = 0;
+    virtual size_t flush()           = 0;
+    virtual void close()             = 0;
 
-//    virtual std::string owner() const = 0;
-    virtual bool exists() const = 0;
+    //    virtual std::string owner() const = 0;
+    virtual bool exists() const   = 0;
     virtual void checkUID() const = 0;
 
     virtual bool canMoveTo(const Key& key, const Config& config, const eckit::URI& dest) const;
-    virtual void moveTo(const Key& key, const Config& config, const eckit::URI& dest, eckit::Queue<MoveElement>& queue) const { NOTIMP; }
+    virtual void moveTo(const Key& key, const Config& config, const eckit::URI& dest,
+                        eckit::Queue<MoveElement>& queue) const {
+        NOTIMP;
+    }
     virtual void remove(const Key& key) const { NOTIMP; }
 
-    virtual eckit::URI uri() const = 0;
-    virtual bool uriBelongs(const eckit::URI&) const = 0;
-    virtual bool uriExists(const eckit::URI& uri) const = 0;
-    virtual std::vector<eckit::URI> collocatedDataURIs() const = 0;
+    virtual eckit::URI uri() const                                                          = 0;
+    virtual bool uriBelongs(const eckit::URI&) const                                        = 0;
+    virtual bool uriExists(const eckit::URI& uri) const                                     = 0;
+    virtual std::vector<eckit::URI> collocatedDataURIs() const                              = 0;
     virtual std::set<eckit::URI> asCollocatedDataURIs(const std::vector<eckit::URI>&) const = 0;
 
     virtual std::vector<eckit::URI> getAuxiliaryURIs(const eckit::URI&) const { NOTIMP; }
@@ -75,6 +81,7 @@ class StoreBuilderBase {
     std::string name_;
 
 public:
+
     StoreBuilderBase(const std::string&);
     virtual ~StoreBuilderBase();
     virtual std::unique_ptr<Store> make(const Key& key, const Config& config) = 0;
@@ -82,15 +89,19 @@ public:
 
 template <class T>
 class StoreBuilder : public StoreBuilderBase {
-    std::unique_ptr<Store> make(const Key& key, const Config& config) override { return std::unique_ptr<T>(new T(key, config)); }
+    std::unique_ptr<Store> make(const Key& key, const Config& config) override {
+        return std::unique_ptr<T>(new T(key, config));
+    }
 
 public:
+
     StoreBuilder(const std::string& name) : StoreBuilderBase(name) {}
     virtual ~StoreBuilder() = default;
 };
 
 class StoreFactory {
 public:
+
     static StoreFactory& instance();
 
     void add(const std::string& name, StoreBuilderBase* builder);
@@ -105,10 +116,11 @@ public:
     std::unique_ptr<Store> build(const Key& key, const Config& config);
 
 private:
+
     StoreFactory();
 
     std::map<std::string, StoreBuilderBase*> builders_;
     eckit::Mutex mutex_;
 };
 
-}
+}  // namespace fdb5
