@@ -22,10 +22,10 @@
 
 #include "fdb5/remote/FdbServer.h"
 
+#include "eckit/config/Resource.h"
 #include "fdb5/remote/server/AvailablePortList.h"
 #include "fdb5/remote/server/CatalogueHandler.h"
 #include "fdb5/remote/server/StoreHandler.h"
-#include "eckit/config/Resource.h"
 
 using namespace eckit;
 
@@ -34,30 +34,31 @@ namespace fdb5::remote {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-FDBForker::FDBForker(net::TCPSocket &socket, const Config &config) :
-    ProcessControler(true),
-    socket_(socket),
-    config_(config) {
-    }
+FDBForker::FDBForker(net::TCPSocket& socket, const Config& config) :
+    ProcessControler(true), socket_(socket), config_(config) {}
 
 FDBForker::~FDBForker() {}
 
 void FDBForker::run() {
 
-    eckit::Monitor::instance().reset(); // needed to the monitor to work on forked (but not execed process)
+    eckit::Monitor::instance().reset();  // needed to the monitor to work on forked (but not execed process)
 
     // Ensure random state is reset after fork
     ::srand(::getpid() + ::time(nullptr));
     ::srandom(::getpid() + ::time(nullptr));
 
-    eckit::Log::info() << "FDB forked pid " << ::getpid() << "  --  connection: " << socket_.localHost() << ":" << socket_.localPort() << "-->" << socket_.remoteHost() << ":" << socket_.remotePort() << std::endl;
+    eckit::Log::info() << "FDB forked pid " << ::getpid() << "  --  connection: " << socket_.localHost() << ":"
+                       << socket_.localPort() << "-->" << socket_.remoteHost() << ":" << socket_.remotePort()
+                       << std::endl;
 
-    if (config_.getString("type", "local") == "catalogue" || (::getenv("FDB_IS_CAT") && ::getenv("FDB_IS_CAT")[0] == '1')) {
+    if (config_.getString("type", "local") == "catalogue" ||
+        (::getenv("FDB_IS_CAT") && ::getenv("FDB_IS_CAT")[0] == '1')) {
         eckit::Log::info() << "FDB using Catalogue Handler" << std::endl;
         CatalogueHandler handler(socket_, config_);
         handler.handle();
-    } 
-    else if (config_.getString("type", "local") == "store" || (::getenv("FDB_IS_STORE") && ::getenv("FDB_IS_STORE")[0] == '1')) {
+    }
+    else if (config_.getString("type", "local") == "store" ||
+             (::getenv("FDB_IS_STORE") && ::getenv("FDB_IS_STORE")[0] == '1')) {
         eckit::Log::info() << "FDB using Store Handler" << std::endl;
         StoreHandler handler(socket_, config_);
         handler.handle();
@@ -68,36 +69,35 @@ void FDBForker::run() {
 
 class FDBServerThread : public eckit::Thread {
 
-public: // methods
+public:  // methods
 
     FDBServerThread(eckit::net::TCPSocket& socket, const Config& config);
 
-private: // methods
+private:  // methods
 
     virtual void run();
 
-private: // members
+private:  // members
 
     eckit::net::TCPSocket socket_;
     eckit::LocalConfiguration config_;
-
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-FDBServerThread::FDBServerThread(net::TCPSocket& socket, const Config& config) :
-    socket_(socket),
-    config_(config) {}
+FDBServerThread::FDBServerThread(net::TCPSocket& socket, const Config& config) : socket_(socket), config_(config) {}
 
 void FDBServerThread::run() {
     eckit::Log::info() << "FDB started handler thread" << std::endl;
 
-    if (config_.getString("type", "local") == "catalogue" || (::getenv("FDB_IS_CAT") && ::getenv("FDB_IS_CAT")[0] == '1')) {
+    if (config_.getString("type", "local") == "catalogue" ||
+        (::getenv("FDB_IS_CAT") && ::getenv("FDB_IS_CAT")[0] == '1')) {
         eckit::Log::info() << "FDB using Catalogue Handler" << std::endl;
         CatalogueHandler handler(socket_, config_);
         handler.handle();
-    } 
-    else if (config_.getString("type", "local") == "store" || (::getenv("FDB_IS_STORE") && ::getenv("FDB_IS_STORE")[0] == '1')) {
+    }
+    else if (config_.getString("type", "local") == "store" ||
+             (::getenv("FDB_IS_STORE") && ::getenv("FDB_IS_STORE")[0] == '1')) {
         eckit::Log::info() << "FDB using Store Handler" << std::endl;
         StoreHandler handler(socket_, config_);
         handler.handle();
@@ -121,7 +121,7 @@ void FdbServerBase::doRun() {
     // maintains the list of available ports.
     startPortReaperThread(config);
 
-    int port = config.getInt("serverPort", 7654);
+    int port      = config.getInt("serverPort", 7654);
     bool threaded = config.getBool("serverThreaded", false);
 
     net::TCPServer server(net::Port("fdb", port), net::SocketOptions::server().reusePort(true));
@@ -147,22 +147,20 @@ void FdbServerBase::doRun() {
     }
 }
 
-void FdbServerBase::startPortReaperThread(const Config &config) {
+void FdbServerBase::startPortReaperThread(const Config& config) {
 
     if (config.has("dataPortStart")) {
         ASSERT(config.has("dataPortCount"));
 
         int startPort = config.getInt("dataPortStart");
-        size_t count = config.getLong("dataPortCount");
+        size_t count  = config.getLong("dataPortCount");
 
-        eckit::Log::info() << "Using custom port list. startPort=" << startPort
-                           << ", count=" << count << std::endl;
+        eckit::Log::info() << "Using custom port list. startPort=" << startPort << ", count=" << count << std::endl;
 
         AvailablePortList portList(startPort, count);
         portList.initialise();
 
         reaperThread_ = std::thread([startPort, count]() {
-
             AvailablePortList portList(startPort, count);
 
             while (true) {
@@ -171,16 +169,11 @@ void FdbServerBase::startPortReaperThread(const Config &config) {
             }
         });
     }
-
 }
 
 //----------------------------------------------------------------------------------------------------------------------
 
-FdbServer::FdbServer(int argc, char **argv, const char *home) :
-    eckit::Application(argc, argv, home),
-    FdbServerBase()
-{
-}
+FdbServer::FdbServer(int argc, char** argv, const char* home) : eckit::Application(argc, argv, home), FdbServerBase() {}
 
 FdbServer::~FdbServer() {}
 
@@ -192,4 +185,4 @@ void FdbServer::hookUnique() {}
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5::remote
+}  // namespace fdb5::remote
