@@ -3,6 +3,7 @@
 #include "fdb5/LibFdb5.h"
 #include "fdb5/remote/Connection.h"
 #include "fdb5/remote/Messages.h"
+#include "fdb5/remote/client/Client.h"
 #include "fdb5/remote/client/ClientConnectionRouter.h"
 
 #include "eckit/config/LocalConfiguration.h"
@@ -55,28 +56,26 @@ ClientConnection::ClientConnection(const eckit::net::Endpoint& controlEndpoint,
     defaultEndpoint_(defaultEndpoint),
     id_(1),
     connected_(false),
-    controlStopping_(false),
-    dataStopping_(false),
     dataWriteQueue_(nullptr) {
 
     LOG_DEBUG_LIB(LibFdb5) << "ClientConnection::ClientConnection() controlEndpoint: " << controlEndpoint << std::endl;
 }
 
 void ClientConnection::add(Client& client) {
-    std::lock_guard<std::mutex> lock(clientsMutex_);
+    std::lock_guard lock(clientsMutex_);
     clients_[client.id()] = &client;
 }
 
 bool ClientConnection::remove(uint32_t clientID) {
-
-    std::lock_guard<std::mutex> lock(clientsMutex_);
+    std::lock_guard lock(clientsMutex_);
 
     if (clientID > 0) {
 
         auto it = clients_.find(clientID);
 
         if (it != clients_.end()) {
-            Connection::write(Message::Stop, true, clientID, 0);
+            if (valid())
+                Connection::write(Message::Stop, true, clientID, 0);
 
             clients_.erase(it);
         }
@@ -84,6 +83,7 @@ bool ClientConnection::remove(uint32_t clientID) {
 
     if (clients_.empty()) {
         teardown();
+        ClientConnectionRouter::instance().deregister(*this);
     }
 
     return clients_.empty();
@@ -145,8 +145,11 @@ bool ClientConnection::connect(bool singleAttempt) {
 
 void ClientConnection::disconnect() {
 
-    std::lock_guard<std::mutex> lock(clientsMutex_);
+    disconnecting_ = true;
+
+    std::lock_guard lock(clientsMutex_);
     ASSERT(clients_.empty());
+
     if (connected_) {
         if (dataWriteThread_.joinable()) {
             dataWriteThread_.join();
@@ -159,8 +162,8 @@ void ClientConnection::disconnect() {
         }
 
         // Close both the control and data connections
-        controlClient_.close();
         dataClient_.close();
+        controlClient_.close();
         connected_ = false;
     }
 }
@@ -347,7 +350,8 @@ void ClientConnection::listeningControlThreadLoop() {
                                    << std::endl;
 
             if (hdr.message == Message::Exit) {
-                controlStopping_ = true;
+                LOG_DEBUG_LIB(LibFdb5) << "ClientConnection::listeningControlThreadLoop() -- Control thread stopping"
+                                       << std::endl;
                 return;
             }
             else {
@@ -372,7 +376,7 @@ void ClientConnection::listeningControlThreadLoop() {
                     else {
                         Client* client = nullptr;
                         {
-                            std::lock_guard<std::mutex> lock(clientsMutex_);
+                            std::lock_guard lock(clientsMutex_);
 
                             auto it = clients_.find(hdr.clientID());
                             if (it == clients_.end()) {
@@ -419,6 +423,16 @@ void ClientConnection::listeningControlThreadLoop() {
     }
 }
 
+void ClientConnection::closeConnection() {
+    LOG_DEBUG_LIB(LibFdb5) << "ClientConnection::closeConnection() -- Data thread stopping" << std::endl;
+    if (!disconnecting_) {
+        std::lock_guard lock(clientsMutex_);
+        for (auto& [id, client] : clients_) {
+            client->closeConnection();
+        }
+    };
+}
+
 void ClientConnection::listeningDataThreadLoop() {
 
     try {
@@ -436,7 +450,7 @@ void ClientConnection::listeningDataThreadLoop() {
                                    << std::endl;
 
             if (hdr.message == Message::Exit) {
-                dataStopping_ = true;
+                closeConnection();
                 return;
             }
             else {
@@ -444,7 +458,7 @@ void ClientConnection::listeningDataThreadLoop() {
                     bool handled   = false;
                     Client* client = nullptr;
                     {
-                        std::lock_guard<std::mutex> lock(clientsMutex_);
+                        std::lock_guard lock(clientsMutex_);
 
                         auto it = clients_.find(hdr.clientID());
                         if (it == clients_.end()) {
