@@ -37,6 +37,7 @@ class ClientConnection : protected Connection {
 public:  // methods
 
     ~ClientConnection() override;
+    ClientConnection(const eckit::net::Endpoint& controlEndpoint, const std::string& defaultEndpoint);
 
     std::future<eckit::Buffer> controlWrite(const Client& client, Message msg, uint32_t requestID,
                                             bool /*dataListener*/, PayloadList payload = {}) const;
@@ -53,12 +54,12 @@ public:  // methods
     const eckit::net::Endpoint& controlEndpoint() const;
     const std::string& defaultEndpoint() const { return defaultEndpoint_; }
 
+    using Connection::valid;
+
 private:  // methods
 
     friend class ClientConnectionRouter;
 
-    ClientConnection(const eckit::net::Endpoint& controlEndpoint, const std::string& defaultEndpoint);
-
     void dataWrite(DataWriteRequest& request) const;
 
     // construct dictionary for protocol negotiation - to be defined in the client class
@@ -74,6 +75,7 @@ private:  // methods
     void listeningControlThreadLoop();
     void listeningDataThreadLoop();
     void dataWriteThreadLoop();
+    void closeConnection();
 
     const eckit::net::TCPSocket& controlSocket() const override { return controlClient_; }
 
@@ -91,6 +93,8 @@ private:  // members
     eckit::net::TCPClient controlClient_;
     eckit::net::TCPClient dataClient_;
 
+    bool disconnecting_ = false;
+
     std::mutex clientsMutex_;
     std::map<uint32_t, Client*> clients_;
 
@@ -104,8 +108,6 @@ private:  // members
     uint32_t id_;
 
     bool connected_;
-    bool controlStopping_;
-    bool dataStopping_;
 
     mutable std::mutex promisesMutex_;
 
