@@ -27,9 +27,11 @@ namespace fdb5::remote {
 class RemoteCatalogue : public CatalogueReader, public CatalogueWriter, public CatalogueImpl, public Client {
 
 public:  // types
+
     static const char* typeName() { return "remote"; }
 
 public:  // methods
+
     RemoteCatalogue(const Key& key, const Config& config);
     RemoteCatalogue(const eckit::URI& uri, const Config& config);
 
@@ -40,7 +42,7 @@ public:  // methods
     void index(const Key& key, const eckit::URI& uri, eckit::Offset offset, eckit::Length length) override;
     void reconsolidate() override;
 
-    //From CatalogueReader
+    // From CatalogueReader
     DbStats stats() const override { return {}; }
     bool retrieve(const Key& /*key*/, Field& /*field*/) const override { return false; }
 
@@ -53,13 +55,16 @@ public:  // methods
 
     std::vector<eckit::PathName> metadataPaths() const override;
     void visitEntries(EntryVisitor& visitor, bool sorted = false) override;
-    void dump(std::ostream& out, bool simple=false, const eckit::Configuration& conf = eckit::LocalConfiguration()) const override;
+    void dump(std::ostream& out, bool simple = false,
+              const eckit::Configuration& conf = eckit::LocalConfiguration()) const override;
     StatsReportVisitor* statsReportVisitor() const override;
     PurgeVisitor* purgeVisitor(const Store& store) const override;
-    WipeVisitor* wipeVisitor(const Store& store, const metkit::mars::MarsRequest& request, std::ostream& out, bool doit, bool porcelain, bool unsafeWipeAll) const override;
-    MoveVisitor* moveVisitor(const Store& store, const metkit::mars::MarsRequest& request, const eckit::URI& dest, eckit::Queue<MoveElement>& queue) const override;
+    WipeVisitor* wipeVisitor(const Store& store, const metkit::mars::MarsRequest& request, std::ostream& out, bool doit,
+                             bool porcelain, bool unsafeWipeAll) const override;
+    MoveVisitor* moveVisitor(const Store& store, const metkit::mars::MarsRequest& request, const eckit::URI& dest,
+                             eckit::Queue<MoveElement>& queue) const override;
     void control(const ControlAction& action, const ControlIdentifiers& identifiers) const override;
-    std::vector<fdb5::Index> indexes(bool sorted=false) const override;
+    std::vector<fdb5::Index> indexes(bool sorted = false) const override;
     void maskIndexEntry(const Index& index) const override;
     void allMasked(std::set<std::pair<eckit::URI, eckit::Offset>>& metadata, std::set<eckit::URI>& data) const override;
     void print(std::ostream& out) const override;
@@ -79,6 +84,7 @@ protected:
     void loadSchema() override;
 
 private:
+
     // From Client
     // handlers for incoming messages - to be defined in the client class
     bool handle(Message message, uint32_t requestID) override;
@@ -96,9 +102,9 @@ private:
     mutable std::unique_ptr<Schema> schema_;
 
     std::mutex archiveMutex_;
-    size_t     numLocations_ {0};
+    size_t numLocations_{0};
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5::remote
+}  // namespace fdb5::remote
