@@ -37,7 +37,7 @@ namespace fdb5::remote {
 //
 // ***************************************************************************************
 
-CatalogueHandler::CatalogueHandler(eckit::net::TCPSocket& socket, const Config& config):
+CatalogueHandler::CatalogueHandler(eckit::net::TCPSocket& socket, const Config& config) :
     ServerConnection(socket, config), fdbControlConnection_(false), fdbDataConnection_(false) {}
 
 CatalogueHandler::~CatalogueHandler() {}
@@ -46,28 +46,28 @@ Handled CatalogueHandler::handleControl(Message message, uint32_t clientID, uint
 
     try {
         switch (message) {
-            case Message::Schema: // request top-level schema
-                {
-                    std::lock_guard<std::mutex> lock(handlerMutex_);
-                    auto it = fdbs_.find(clientID);
-                    if (it == fdbs_.end()) {
-                        fdbs_[clientID];
-                        fdbControlConnection_ = true;
-                        fdbDataConnection_ = !single_;
-                        numControlConnection_++;
-                        if (fdbDataConnection_)
-                            numDataConnection_++;
-                    }
+            case Message::Schema:  // request top-level schema
+            {
+                std::lock_guard<std::mutex> lock(handlerMutex_);
+                auto it = fdbs_.find(clientID);
+                if (it == fdbs_.end()) {
+                    fdbs_[clientID];
+                    fdbControlConnection_ = true;
+                    fdbDataConnection_    = !single_;
+                    numControlConnection_++;
+                    if (fdbDataConnection_)
+                        numDataConnection_++;
                 }
+            }
                 schema(clientID, requestID, eckit::Buffer(0));
                 return Handled::Replied;
 
-            case Message::Stores: // request the list of FDB stores and the corresponging endpoints
+            case Message::Stores:  // request the list of FDB stores and the corresponging endpoints
                 stores(clientID, requestID);
                 return Handled::Replied;
 
 
-            case Message::Archive: // notification that the client is starting to send data locations for archival
+            case Message::Archive:  // notification that the client is starting to send data locations for archival
                 archiver();
                 return Handled::YesAddArchiveListener;
 
@@ -90,32 +90,33 @@ Handled CatalogueHandler::handleControl(Message message, uint32_t clientID, uint
     return Handled::No;
 }
 
-Handled CatalogueHandler::handleControl(Message message, uint32_t clientID, uint32_t requestID, eckit::Buffer&& payload) {
+Handled CatalogueHandler::handleControl(Message message, uint32_t clientID, uint32_t requestID,
+                                        eckit::Buffer&& payload) {
 
     try {
         switch (message) {
 
-            case Message::Schema: // request catalogue schema
+            case Message::Schema:  // request catalogue schema
                 schema(clientID, requestID, std::move(payload));
                 return Handled::Replied;
 
-            case Message::List: // list request. Location are sent aynchronously over the data connection
+            case Message::List:  // list request. Location are sent aynchronously over the data connection
                 list(clientID, requestID, std::move(payload));
                 return Handled::Yes;
 
-            case Message::Axes: // list request. Location are sent aynchronously over the data connection
+            case Message::Axes:  // list request. Location are sent aynchronously over the data connection
                 axes(clientID, requestID, std::move(payload));
                 return Handled::Yes;
 
-            case Message::Inspect: // inspect request. Location are sent aynchronously over the data connection
+            case Message::Inspect:  // inspect request. Location are sent aynchronously over the data connection
                 inspect(clientID, requestID, std::move(payload));
                 return Handled::Yes;
 
-            case Message::Stats: // inspect request. Location are sent aynchronously over the data connection
+            case Message::Stats:  // inspect request. Location are sent aynchronously over the data connection
                 stats(clientID, requestID, std::move(payload));
                 return Handled::Yes;
 
-            case Message::Flush: // flush catalogue
+            case Message::Flush:  // flush catalogue
                 flush(clientID, requestID, std::move(payload));
                 return Handled::Yes;
 
@@ -181,26 +182,20 @@ struct ListHelper : public BaseHelper<ListElement> {
 struct AxesHelper : public BaseHelper<AxesElement> {
     virtual size_t encodeBufferSize(const AxesElement& el) const { return el.encodeSize(); }
 
-    void extraDecode(eckit::Stream& s) {
-        s >> level_;
-    }
-    AxesIterator apiCall(FDB& fdb, const FDBToolRequest& request) const {
-        return fdb.axesIterator(request, level_);
-    }
+    void extraDecode(eckit::Stream& s) { s >> level_; }
+    AxesIterator apiCall(FDB& fdb, const FDBToolRequest& request) const { return fdb.axesIterator(request, level_); }
+
 private:
+
     int level_;
 };
 
 struct InspectHelper : public BaseHelper<ListElement> {
-    ListIterator apiCall(FDB& fdb, const FDBToolRequest& request) const {
-        return fdb.inspect(request.request());
-    }
+    ListIterator apiCall(FDB& fdb, const FDBToolRequest& request) const { return fdb.inspect(request.request()); }
 };
 
 struct StatsHelper : public BaseHelper<StatsElement> {
-    StatsIterator apiCall(FDB& fdb, const FDBToolRequest& request) const {
-        return fdb.stats(request);
-    }
+    StatsIterator apiCall(FDB& fdb, const FDBToolRequest& request) const { return fdb.stats(request); }
 };
 
 template <typename HelperClass>
@@ -223,35 +218,33 @@ void CatalogueHandler::forwardApiCall(uint32_t clientID, uint32_t requestID, eck
         }
     }
 
-    workerThreads_.emplace(
-        requestID, std::async(std::launch::async, [request, clientID, requestID, helper, this]() {
-
-            try {
-                FDB* fdb = nullptr;
-                {
-                    std::lock_guard<std::mutex> lock(handlerMutex_);
-                    auto it = fdbs_.find(clientID);
-                    ASSERT(it != fdbs_.end());
-                    fdb = &it->second;
-                    ASSERT(fdb);
-                }
-                auto iterator = helper.apiCall(*fdb, request);
-                typename decltype(iterator)::value_type elem;
-                while (iterator.next(elem)) {
-                    auto encoded(helper.encode(elem, *this));
-                    write(Message::Blob, false, clientID, requestID, encoded.buf, encoded.position);
-                }
-                write(Message::Complete, false, clientID, requestID);
-            }
-            catch (std::exception& e) {
-                // n.b. more general than eckit::Exception
-                error(e.what(), clientID, requestID);
-            }
-            catch (...) {
-                // We really don't want to std::terminate the thread
-                error("Caught unexpected, unknown exception in worker", clientID, requestID);
-            }
-        }));
+    workerThreads_.emplace(requestID, std::async(std::launch::async, [request, clientID, requestID, helper, this]() {
+                               try {
+                                   FDB* fdb = nullptr;
+                                   {
+                                       std::lock_guard<std::mutex> lock(handlerMutex_);
+                                       auto it = fdbs_.find(clientID);
+                                       ASSERT(it != fdbs_.end());
+                                       fdb = &it->second;
+                                       ASSERT(fdb);
+                                   }
+                                   auto iterator = helper.apiCall(*fdb, request);
+                                   typename decltype(iterator)::value_type elem;
+                                   while (iterator.next(elem)) {
+                                       auto encoded(helper.encode(elem, *this));
+                                       write(Message::Blob, false, clientID, requestID, encoded.buf, encoded.position);
+                                   }
+                                   write(Message::Complete, false, clientID, requestID);
+                               }
+                               catch (std::exception& e) {
+                                   // n.b. more general than eckit::Exception
+                                   error(e.what(), clientID, requestID);
+                               }
+                               catch (...) {
+                                   // We really don't want to std::terminate the thread
+                                   error("Caught unexpected, unknown exception in worker", clientID, requestID);
+                               }
+                           }));
 }
 
 void CatalogueHandler::list(uint32_t clientID, uint32_t requestID, eckit::Buffer&& payload) {
@@ -272,18 +265,19 @@ void CatalogueHandler::stats(uint32_t clientID, uint32_t requestID, eckit::Buffe
 
 void CatalogueHandler::schema(uint32_t clientID, uint32_t requestID, eckit::Buffer&& payload) {
 
-    eckit::Buffer schemaBuffer(256*1024);
+    eckit::Buffer schemaBuffer(256 * 1024);
     eckit::MemoryStream stream(schemaBuffer);
 
-    if (payload.size() == 0) { // client requesting the top-level schema
+    if (payload.size() == 0) {  // client requesting the top-level schema
         stream << config_.schema();
-    } else {
+    }
+    else {
         // 1. Read dbkey to select catalogue
         MemoryStream s(payload);
         Key dbKey(s);
 
         // 2. Get catalogue
-        Catalogue& cat = catalogue(clientID, dbKey);
+        Catalogue& cat       = catalogue(clientID, dbKey);
         const Schema& schema = cat.schema();
         stream << schema;
     }
@@ -297,7 +291,7 @@ void CatalogueHandler::stores(uint32_t clientID, uint32_t requestID) {
 
     std::string clientNetwork = "";
     if (config_.has("networks")) {
-        for (const auto& net: config_.getSubConfigurations("networks")) {
+        for (const auto& net : config_.getSubConfigurations("networks")) {
             if (net.has("name") && net.has("netmask")) {
                 eckit::net::NetMask netmask{net.getString("netmask")};
                 if (netmask.contains(clientIPaddress)) {
@@ -312,7 +306,7 @@ void CatalogueHandler::stores(uint32_t clientID, uint32_t requestID) {
 
     ASSERT(config_.has("stores"));
     std::map<std::string, std::vector<eckit::net::Endpoint>> stores;
-    for (const auto& configStore: config_.getSubConfigurations("stores")) {
+    for (const auto& configStore : config_.getSubConfigurations("stores")) {
         ASSERT(configStore.has("default"));
         eckit::net::Endpoint fieldLocationEndpoint{configStore.getString("default")};
         eckit::net::Endpoint storeEndpoint{fieldLocationEndpoint};
@@ -325,7 +319,8 @@ void CatalogueHandler::stores(uint32_t clientID, uint32_t requestID) {
         auto it = stores.find(fieldLocationEndpoint);
         if (it == stores.end()) {
             stores.emplace(fieldLocationEndpoint, std::vector<eckit::net::Endpoint>{storeEndpoint});
-        } else {
+        }
+        else {
             it->second.push_back(storeEndpoint);
         }
 
@@ -333,20 +328,21 @@ void CatalogueHandler::stores(uint32_t clientID, uint32_t requestID) {
             it = stores.find("");
             if (it == stores.end()) {
                 stores.emplace("", std::vector<eckit::net::Endpoint>{storeEndpoint});
-            } else {
+            }
+            else {
                 it->second.push_back(storeEndpoint);
             }
         }
     }
 
     {
-        Buffer startupBuffer(16*1024);
+        Buffer startupBuffer(16 * 1024);
         MemoryStream s(startupBuffer);
 
         s << stores.size();
         for (const auto& store : stores) {
             s << store.first << store.second.size();
-            for (const auto& ee: store.second) {
+            for (const auto& ee : store.second) {
                 s << ee;
             }
         }
@@ -366,7 +362,7 @@ void CatalogueHandler::exists(uint32_t clientID, uint32_t requestID, eckit::Buff
         exists = CatalogueReaderFactory::instance().build(dbKey, config_)->exists();
     }
 
-    eckit::Buffer       existBuf(5);
+    eckit::Buffer existBuf(5);
     eckit::MemoryStream stream(existBuf);
     stream << exists;
 
@@ -390,7 +386,8 @@ void CatalogueHandler::flush(uint32_t clientID, uint32_t requestID, eckit::Buffe
 
     {
         std::lock_guard<std::mutex> lock(fieldLocationsMutex_);
-        it->second.locationsExpected = numArchived;     // setting locationsExpected also means that a flush has been requested
+        it->second.locationsExpected =
+            numArchived;  // setting locationsExpected also means that a flush has been requested
         it->second.archivalCompleted = it->second.fieldLocationsReceived.get_future();
         if (it->second.locationsArchived == numArchived) {
             it->second.fieldLocationsReceived.set_value(numArchived);
@@ -401,8 +398,8 @@ void CatalogueHandler::flush(uint32_t clientID, uint32_t requestID, eckit::Buffe
     {
         std::lock_guard<std::mutex> lock(fieldLocationsMutex_);
         it->second.fieldLocationsReceived = std::promise<size_t>{};
-        it->second.locationsExpected = 0;
-        it->second.locationsArchived = 0;
+        it->second.locationsExpected      = 0;
+        it->second.locationsArchived      = 0;
     }
 
     it->second.catalogue->flush(numArchived);
@@ -421,7 +418,8 @@ void CatalogueHandler::archiveBlob(const uint32_t clientID, const uint32_t reque
 
     std::unique_ptr<FieldLocation> location(eckit::Reanimator<FieldLocation>::reanimate(s));
 
-    LOG_DEBUG_LIB(LibFdb5) << "CatalogueHandler::archiveBlob key: " << idxKey << datumKey << "  location: " << location->uri() << std::endl;
+    LOG_DEBUG_LIB(LibFdb5) << "CatalogueHandler::archiveBlob key: " << idxKey << datumKey
+                           << "  location: " << location->uri() << std::endl;
 
     std::map<uint32_t, CatalogueArchiver>::iterator it;
     {
@@ -439,7 +437,8 @@ void CatalogueHandler::archiveBlob(const uint32_t clientID, const uint32_t reque
     {
         std::lock_guard<std::mutex> lock(fieldLocationsMutex_);
         it->second.locationsArchived++;
-        if (it->second.locationsExpected != 0 && it->second.archivalCompleted.valid() && it->second.locationsExpected == it->second.locationsArchived) {
+        if (it->second.locationsExpected != 0 && it->second.archivalCompleted.valid() &&
+            it->second.locationsExpected == it->second.locationsArchived) {
             it->second.fieldLocationsReceived.set_value(it->second.locationsExpected);
         }
     }
@@ -455,18 +454,21 @@ bool CatalogueHandler::remove(bool control, uint32_t clientID) {
         if (control) {
             fdbControlConnection_ = false;
             numControlConnection_--;
-        } else {
+        }
+        else {
             fdbDataConnection_ = false;
             numDataConnection_--;
         }
-    } else {
+    }
+    else {
 
         auto it = catalogues_.find(clientID);
         if (it != catalogues_.end()) {
             if (control) {
                 it->second.controlConnection = false;
                 numControlConnection_--;
-            } else {
+            }
+            else {
                 it->second.dataConnection = false;
                 numDataConnection_--;
             }
