@@ -11,18 +11,18 @@
 #include "fdb5/fdb5_config.h"
 
 #include "eckit/config/Resource.h"
-#include "eckit/log/Log.h"
-#include "eckit/log/Bytes.h"
 #include "eckit/io/EmptyHandle.h"
+#include "eckit/log/Bytes.h"
+#include "eckit/log/Log.h"
 
+#include "fdb5/LibFdb5.h"
 #include "fdb5/database/EntryVisitMechanism.h"
 #include "fdb5/io/FDBFileHandle.h"
-#include "fdb5/LibFdb5.h"
+#include "fdb5/io/LustreSettings.h"
+#include "fdb5/toc/RootManager.h"
 #include "fdb5/toc/TocCatalogueWriter.h"
 #include "fdb5/toc/TocFieldLocation.h"
 #include "fdb5/toc/TocIndex.h"
-#include "fdb5/toc/RootManager.h"
-#include "fdb5/io/LustreSettings.h"
 
 using namespace eckit;
 
@@ -32,18 +32,14 @@ namespace fdb5 {
 
 
 TocCatalogueWriter::TocCatalogueWriter(const Key& dbKey, const fdb5::Config& config) :
-    TocCatalogue(dbKey, config),
-    umask_(config.umask()),
-    archivedLocations_(0) {
+    TocCatalogue(dbKey, config), umask_(config.umask()), archivedLocations_(0) {
     writeInitRecord(dbKey);
     TocCatalogue::loadSchema();
     TocCatalogue::checkUID();
 }
 
-TocCatalogueWriter::TocCatalogueWriter(const eckit::URI &uri, const fdb5::Config& config) :
-    TocCatalogue(uri.path(), ControlIdentifiers{}, config),
-    umask_(config.umask()),
-    archivedLocations_(0) {
+TocCatalogueWriter::TocCatalogueWriter(const eckit::URI& uri, const fdb5::Config& config) :
+    TocCatalogue(uri.path(), ControlIdentifiers{}, config), umask_(config.umask()), archivedLocations_(0) {
     writeInitRecord(TocCatalogue::key());
     TocCatalogue::loadSchema();
     TocCatalogue::checkUID();
@@ -66,7 +62,7 @@ bool TocCatalogueWriter::selectIndex(const Key& idxKey) {
             fdb5LustreapiFileCreate(indexPath, stripeIndexLustreSettings());
         }
 
-        indexes_[idxKey] = Index(new TocIndex(idxKey, *this, indexPath, 0, TocIndex::WRITE));
+        indexes_[idxKey] = Index(new TocIndex(idxKey, indexPath, 0, TocIndex::WRITE));
     }
 
     current_ = indexes_[idxKey];
@@ -88,7 +84,7 @@ bool TocCatalogueWriter::selectIndex(const Key& idxKey) {
                 fdb5LustreapiFileCreate(indexPath, stripeIndexLustreSettings());
             }
 
-            fullIndexes_[idxKey] = Index(new TocIndex(idxKey, *this, indexPath, 0, TocIndex::WRITE));
+            fullIndexes_[idxKey] = Index(new TocIndex(idxKey, indexPath, 0, TocIndex::WRITE));
         }
 
         currentFull_ = fullIndexes_[idxKey];
@@ -100,8 +96,8 @@ bool TocCatalogueWriter::selectIndex(const Key& idxKey) {
 }
 
 void TocCatalogueWriter::deselectIndex() {
-    current_ = Index();
-    currentFull_ = Index();
+    current_         = Index();
+    currentFull_     = Index();
     currentIndexKey_ = Key();
 }
 
@@ -113,7 +109,7 @@ void TocCatalogueWriter::clean() {
 
     LOG_DEBUG_LIB(LibFdb5) << "Closing path " << directory_ << std::endl;
 
-    flush(archivedLocations_); // closes the TOC entries & indexes but not data files
+    flush(archivedLocations_);  // closes the TOC entries & indexes but not data files
 
     compactSubTocIndexes();
 
@@ -125,7 +121,7 @@ void TocCatalogueWriter::close() {
     closeIndexes();
 }
 
-void TocCatalogueWriter::index(const Key& key, const eckit::URI &uri, eckit::Offset offset, eckit::Length length) {
+void TocCatalogueWriter::index(const Key& key, const eckit::URI& uri, eckit::Offset offset, eckit::Length length) {
     archivedLocations_++;
 
     if (current_.null()) {
@@ -151,10 +147,12 @@ void TocCatalogueWriter::reconsolidateIndexesAndTocs() {
 
     class ConsolidateIndexVisitor : public EntryVisitor {
     public:
-        ConsolidateIndexVisitor(TocCatalogueWriter& writer) :
-            writer_(writer) {}
+
+        ConsolidateIndexVisitor(TocCatalogueWriter& writer) : writer_(writer) {}
         ~ConsolidateIndexVisitor() override {}
+
     private:
+
         void visitDatum(const Field& field, const Key& datumKey) override {
             /// @todo Do a sneaky schema.expand() here, prepopulated with the current DB/index/Rule,
             //       to extract the full key, including optional values.
@@ -173,7 +171,7 @@ void TocCatalogueWriter::reconsolidateIndexesAndTocs() {
     std::set<std::string> subtocs;
     std::vector<bool> indexInSubtoc;
     std::vector<Index> readIndexes = loadIndexes(false, &subtocs, &indexInSubtoc);
-    size_t maskable_indexes = 0;
+    size_t maskable_indexes        = 0;
 
     ConsolidateIndexVisitor visitor(*this);
 
@@ -187,7 +185,8 @@ void TocCatalogueWriter::reconsolidateIndexesAndTocs() {
         Log::info() << "Visiting index: " << idx.location().uri() << std::endl;
 
         // We need to explicitly mask indexes in the master TOC
-        if (!indexInSubtoc[i]) maskable_indexes += 1;
+        if (!indexInSubtoc[i])
+            maskable_indexes += 1;
     }
 
     // Flush the new indexes and add relevant entries!
@@ -265,7 +264,8 @@ void TocCatalogueWriter::overlayDB(const Catalogue& otherCat, const std::set<std
         if (kv.second != it->second) {
             if (variableKeys.find(kv.first) == variableKeys.end()) {
                 std::stringstream ss;
-                ss << "Key " << kv.first << " not allowed to differ between DBs: " << TocCatalogue::dbKey_ << " : " << otherKey;
+                ss << "Key " << kv.first << " not allowed to differ between DBs: " << TocCatalogue::dbKey_ << " : "
+                   << otherKey;
                 throw UserError(ss.str(), Here());
             }
         }
@@ -287,7 +287,8 @@ void TocCatalogueWriter::overlayDB(const Catalogue& otherCat, const std::set<std
         }
 
         writeSubTocMaskRecord(otherCatalogue);
-    } else {
+    }
+    else {
         writeSubTocRecord(otherCatalogue);
     }
 }
@@ -303,15 +304,18 @@ bool TocCatalogueWriter::enabled(const ControlIdentifier& controlIdentifier) con
     return TocCatalogue::enabled(controlIdentifier);
 }
 
-void TocCatalogueWriter::archive(const Key& idxKey, const Key& datumKey, std::shared_ptr<const FieldLocation> fieldLocation) {
+void TocCatalogueWriter::archive(const Key& idxKey, const Key& datumKey,
+                                 std::shared_ptr<const FieldLocation> fieldLocation) {
     archivedLocations_++;
 
     if (current_.null()) {
         ASSERT(!currentIndexKey_.empty());
         selectIndex(currentIndexKey_);
-    } else {
-        // in case of async archival (out of order store/catalogue archival), currentIndexKey_ can differ from the indexKey used for store archival. Reset it
-        if(currentIndexKey_ != idxKey) {
+    }
+    else {
+        // in case of async archival (out of order store/catalogue archival), currentIndexKey_ can differ from the
+        // indexKey used for store archival. Reset it
+        if (currentIndexKey_ != idxKey) {
             selectIndex(idxKey);
         }
     }
@@ -334,12 +338,12 @@ void TocCatalogueWriter::flush(size_t archivedFields) {
     flushIndexes();
 
     archivedLocations_ = 0;
-    current_ = Index();
-    currentFull_ = Index();
+    current_           = Index();
+    currentFull_       = Index();
 }
 
 eckit::PathName TocCatalogueWriter::generateIndexPath(const Key& key) const {
-    eckit::PathName tocPath ( directory_ );
+    eckit::PathName tocPath(directory_);
     tocPath /= key.valuesToString();
     tocPath = eckit::PathName::unique(tocPath) + ".index";
     return tocPath;
@@ -351,31 +355,31 @@ eckit::PathName TocCatalogueWriter::generateIndexPath(const Key& key) const {
 // the data that is indexes thorughout the lifetime of the DBWriter, which can be
 // compacted later for read performance.
 void TocCatalogueWriter::flushIndexes() {
-    for (IndexStore::iterator j = indexes_.begin(); j != indexes_.end(); ++j ) {
+    for (IndexStore::iterator j = indexes_.begin(); j != indexes_.end(); ++j) {
         Index& idx = j->second;
 
         if (idx.dirty()) {
             idx.flush();
             writeIndexRecord(idx);
-            idx.reopen(); // Create a new btree
+            idx.reopen();  // Create a new btree
         }
     }
 }
 
 
 void TocCatalogueWriter::closeIndexes() {
-    for (IndexStore::iterator j = indexes_.begin(); j != indexes_.end(); ++j ) {
+    for (IndexStore::iterator j = indexes_.begin(); j != indexes_.end(); ++j) {
         Index& idx = j->second;
         idx.close();
     }
 
-    for (IndexStore::iterator j = fullIndexes_.begin(); j != fullIndexes_.end(); ++j ) {
+    for (IndexStore::iterator j = fullIndexes_.begin(); j != fullIndexes_.end(); ++j) {
         Index& idx = j->second;
         idx.close();
     }
 
-    indexes_.clear(); // all indexes instances destroyed
-    fullIndexes_.clear(); // all indexes instances destroyed
+    indexes_.clear();      // all indexes instances destroyed
+    fullIndexes_.clear();  // all indexes instances destroyed
 }
 
 void TocCatalogueWriter::compactSubTocIndexes() {
@@ -416,7 +420,7 @@ void TocCatalogueWriter::compactSubTocIndexes() {
 }
 
 
-void TocCatalogueWriter::print(std::ostream &out) const {
+void TocCatalogueWriter::print(std::ostream& out) const {
     out << "TocCatalogueWriter(" << directory() << ")";
 }
 
@@ -424,4 +428,4 @@ static CatalogueWriterBuilder<TocCatalogueWriter> builder("toc");
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
