@@ -136,6 +136,7 @@ std::map<eckit::PathName, const Rule*> TocEngine::databases(const std::map<Key,
 
         LOG_DEBUG_LIB(LibFdb5) << "Scanning for TOC FDBs in root " << *j << std::endl;
 
+        std::string regex_prefix = "^" + eckit::StringTools::lower(Regex::escape(j->asString())) + "/";
         std::list<std::string> dbs;
         scan_dbs(*j, dbs);
 
@@ -146,23 +147,21 @@ std::map<eckit::PathName, const Rule*> TocEngine::databases(const std::map<Key,
 
             for (const std::string& dbpath : dbpaths) {
 
-                std::string regex = "^" + Regex::escape(j->asString()) + "/" + dbpath + "$";
-                std::regex reg(regex, std::regex::icase | std::regex::optimize);
+                std::string regex = regex_prefix + eckit::StringTools::lower(dbpath) + "$";
+                eckit::Regex reg(regex);
 
                 LOG_DEBUG_LIB(LibFdb5) << " -> key " << key << " dbpath " << dbpath << " pathregex " << regex
                                        << std::endl;
 
-                std::smatch m;
-                for (std::list<std::string>::const_iterator k = dbs.begin(); k != dbs.end(); ++k) {
+                for (const auto& db : dbs) {
 
-                    LOG_DEBUG_LIB(LibFdb5) << "    -> db " << *k << std::endl;
+                    LOG_DEBUG_LIB(LibFdb5) << "    -> db " << db << std::endl;
 
-                    if (result.find(*k) != result.end()) {
+                    if (result.find(db) != result.end()) {
                         continue;
                     }
-
-                    if (std::regex_match(*k, m, reg)) {
-                        result[*k] = rule;
+                    if (reg.match(eckit::StringTools::lower(db))) {
+                        result[db] = rule;
                     }
                 }
             }
