@@ -21,11 +21,12 @@ namespace fdb5 {
 
 class TocIndexCloser {
 
-    const TocIndex &index_;
+    const TocIndex& index_;
     bool opened_;
 
 public:
-    TocIndexCloser(const TocIndex &index): index_(index), opened_(index.btree_) {
+
+    TocIndexCloser(const TocIndex& index) : index_(index), opened_(index.btree_) {
         if (!opened_) {
             const_cast<TocIndex&>(index_).open();
         }
@@ -45,34 +46,24 @@ public:
 ///       before the type_ members of Index, but Indexs WILL be constructed before
 ///       the members of TocIndex
 
-TocIndex::TocIndex(const Key&             key,
-                   const Catalogue&       catalogue,
-                   const eckit::PathName& path,
-                   off_t                  offset,
-                   Mode                   mode,
-                   const std::string&     type)
-    : UriStoreWrapper(path.dirName()),
-      IndexBase(key, type),
-      btree_(nullptr),
-      dirty_(false),
-      mode_(mode),
-      location_(path, offset),
-      preloadBTree_(false) { }
+TocIndex::TocIndex(const Key& key, const eckit::PathName& path, off_t offset, Mode mode, const std::string& type) :
+    UriStoreWrapper(path.dirName()),
+    IndexBase(key, type),
+    btree_(nullptr),
+    dirty_(false),
+    mode_(mode),
+    location_(path, offset),
+    preloadBTree_(false) {}
 
-TocIndex::TocIndex(eckit::Stream&         s,
-                   const Catalogue&       catalogue,
-                   const int              version,
-                   const eckit::PathName& directory,
-                   const eckit::PathName& path,
-                   off_t                  offset,
-                   bool                   preloadBTree)
-    : UriStoreWrapper(directory, s),
-      IndexBase(s, version),
-      btree_(nullptr),
-      dirty_(false),
-      mode_(TocIndex::READ),
-      location_(path, offset),
-      preloadBTree_(preloadBTree) { }
+TocIndex::TocIndex(eckit::Stream& s, const int version, const eckit::PathName& directory, const eckit::PathName& path,
+                   off_t offset, bool preloadBTree) :
+    UriStoreWrapper(directory, s),
+    IndexBase(s, version),
+    btree_(nullptr),
+    dirty_(false),
+    mode_(TocIndex::READ),
+    location_(path, offset),
+    preloadBTree_(preloadBTree) {}
 
 TocIndex::~TocIndex() {
     close();
@@ -84,16 +75,17 @@ void TocIndex::encode(eckit::Stream& s, const int version) const {
 }
 
 
-bool TocIndex::get(const Key& key, const Key& remapKey, Field &field) const {
+bool TocIndex::get(const Key& key, const Key& remapKey, Field& field) const {
     ASSERT(btree_);
     FieldRef ref;
 
     bool found = btree_->get(key.valuesToString(), ref);
-    if ( found ) {
+    if (found) {
         const eckit::URI& uri = uris_.get(ref.uriId());
-        FieldLocation* loc = FieldLocationFactory::instance().build(uri.scheme(), uri, ref.offset(), ref.length(), remapKey);
+        FieldLocation* loc =
+            FieldLocationFactory::instance().build(uri.scheme(), uri, ref.offset(), ref.length(), remapKey);
         field = Field(std::move(*loc), timestamp_, ref.details());
-        delete(loc);
+        delete (loc);
     }
     return found;
 }
@@ -103,7 +95,8 @@ void TocIndex::open() {
     if (!btree_) {
         LOG_DEBUG_LIB(LibFdb5) << "Opening " << *this << std::endl;
         btree_.reset(BTreeIndexFactory::build(type_, location_.path_, mode_ == TocIndex::READ, location_.offset_));
-        if (mode_ == TocIndex::READ && preloadBTree_) btree_->preload();
+        if (mode_ == TocIndex::READ && preloadBTree_)
+            btree_->preload();
     }
 }
 
@@ -130,21 +123,20 @@ void TocIndex::close() {
     }
 }
 
-void TocIndex::add(const Key& key, const Field &field) {
+void TocIndex::add(const Key& key, const Field& field) {
     ASSERT(btree_);
-    ASSERT( mode_ == TocIndex::WRITE );
+    ASSERT(mode_ == TocIndex::WRITE);
 
     FieldRef ref(uris_, field);
 
     //  bool replace =
-    btree_->set(key.valuesToString(), ref); // returns true if replace, false if new insert
+    btree_->set(key.valuesToString(), ref);  // returns true if replace, false if new insert
 
     dirty_ = true;
-
 }
 
 void TocIndex::flush() {
-    ASSERT( mode_ == TocIndex::WRITE );
+    ASSERT(mode_ == TocIndex::WRITE);
 
     if (dirty_) {
         axes_.sort();
@@ -157,7 +149,7 @@ void TocIndex::flush() {
 }
 
 
-void TocIndex::visit(IndexLocationVisitor &visitor) const {
+void TocIndex::visit(IndexLocationVisitor& visitor) const {
     visitor(location_);
 }
 
@@ -171,12 +163,12 @@ void TocIndex::funlock() const {
 }
 
 class TocIndexVisitor : public BTreeIndexVisitor {
-    const UriStore &uris_;
-    EntryVisitor &visitor_;
+    const UriStore& uris_;
+    EntryVisitor& visitor_;
+
 public:
-    TocIndexVisitor(const UriStore &uris, EntryVisitor &visitor):
-        uris_(uris),
-        visitor_(visitor) {}
+
+    TocIndexVisitor(const UriStore& uris, EntryVisitor& visitor) : uris_(uris), visitor_(visitor) {}
 
     void visit(const std::string& keyFingerprint, const FieldRef& ref) {
 
@@ -185,7 +177,7 @@ public:
     }
 };
 
-void TocIndex::entries(EntryVisitor &visitor) const {
+void TocIndex::entries(EntryVisitor& visitor) const {
 
     Index instantIndex(const_cast<TocIndex*>(this));
 
@@ -197,8 +189,8 @@ void TocIndex::entries(EntryVisitor &visitor) const {
     }
 }
 
-void TocIndex::print(std::ostream &out) const {
-    out << "TocIndex(path=" << location_.path_ << ",offset="<< location_.offset_ << ")";
+void TocIndex::print(std::ostream& out) const {
+    out << "TocIndex(path=" << location_.path_ << ",offset=" << location_.offset_ << ")";
 }
 
 
@@ -218,6 +210,7 @@ bool TocIndex::dirty() const {
 class DumpBTreeVisitor : public BTreeIndexVisitor {
     std::ostream& out_;
     std::string indent_;
+
 public:
 
     DumpBTreeVisitor(std::ostream& out, const std::string& indent) : out_(out), indent_(indent) {}
@@ -230,10 +223,10 @@ public:
 };
 
 
-void TocIndex::dump(std::ostream &out, const char* indent, bool simple, bool dumpFields) const {
+void TocIndex::dump(std::ostream& out, const char* indent, bool simple, bool dumpFields) const {
     out << indent << "Key: " << key_;
 
-    if(!simple) {
+    if (!simple) {
         out << std::endl;
         uris_.dump(out, indent);
         axes_.dump(out, indent);
@@ -250,12 +243,11 @@ void TocIndex::dump(std::ostream &out, const char* indent, bool simple, bool dum
     }
 }
 
-IndexStats TocIndex::statistics() const
-{
+IndexStats TocIndex::statistics() const {
     IndexStats s(new TocIndexStats());
     return s;
 }
 
 //-----------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
