@@ -19,15 +19,15 @@
 #include "eckit/io/EmptyHandle.h"
 
 #include "fdb5/LibFdb5.h"
-#include "fdb5/rules/Rule.h"
 #include "fdb5/database/FieldLocation.h"
-#include "fdb5/toc/TocFieldLocation.h"
+#include "fdb5/io/FDBFileHandle.h"
+#include "fdb5/io/LustreFileHandle.h"
+#include "fdb5/rules/Rule.h"
 #include "fdb5/toc/RootManager.h"
+#include "fdb5/toc/TocFieldLocation.h"
 #include "fdb5/toc/TocPurgeVisitor.h"
 #include "fdb5/toc/TocStats.h"
 #include "fdb5/toc/TocStore.h"
-#include "fdb5/io/FDBFileHandle.h"
-#include "fdb5/io/LustreFileHandle.h"
 
 using namespace eckit;
 
@@ -38,19 +38,18 @@ namespace fdb5 {
 TocStore::TocStore(const Key& key, const Config& config) :
     Store(),
     TocCommon(StoreRootManager(config).directory(key).directory_),
-    archivedFields_(0), auxFileExtensions_{auxFileExtensions()} {}
+    archivedFields_(0),
+    auxFileExtensions_{auxFileExtensions()} {}
 
 eckit::URI TocStore::uri() const {
 
     return URI("file", directory_);
-
 }
 
 bool TocStore::uriBelongs(const eckit::URI& uri) const {
 
     // TODO: assert uri represents a (not necessarily existing) data file
     return ((uri.scheme() == type()) && (uri.path().dirName().sameAs(directory_)));
-
 }
 
 bool TocStore::uriExists(const eckit::URI& uri) const {
@@ -64,10 +63,9 @@ bool TocStore::uriExists(const eckit::URI& uri) const {
     }
 
     return p.exists();
-
 }
 
-bool TocStore::auxiliaryURIExists(const eckit::URI& uri) const  {
+bool TocStore::auxiliaryURIExists(const eckit::URI& uri) const {
     ASSERT(uri.scheme() == type());
     eckit::PathName p(uri.path());
     ASSERT(p.dirName().sameAs(directory_));
@@ -88,7 +86,6 @@ std::vector<eckit::URI> TocStore::collocatedDataURIs() const {
     }
 
     return res;
-
 }
 
 std::set<eckit::URI> TocStore::asCollocatedDataURIs(const std::vector<eckit::URI>& uris) const {
@@ -99,17 +96,14 @@ std::set<eckit::URI> TocStore::asCollocatedDataURIs(const std::vector<eckit::URI
 
         ASSERT(uri.path().extension() == ".data");
         res.insert(uri);
-
     }
 
     return res;
-
 }
 
 bool TocStore::exists() const {
 
     return directory_.exists();
-
 }
 
 eckit::DataHandle* TocStore::retrieve(Field& field) const {
@@ -121,11 +115,11 @@ std::unique_ptr<const FieldLocation> TocStore::archive(const Key& idxKey, const
 
     eckit::PathName dataPath = getDataPath(idxKey);
 
-    eckit::DataHandle &dh = getDataHandle(dataPath);
+    eckit::DataHandle& dh = getDataHandle(dataPath);
 
     eckit::Offset position = dh.position();
 
-    long len = dh.write( data, length );
+    long len = dh.write(data, length);
 
     ASSERT(len == length);
 
@@ -140,7 +134,7 @@ size_t TocStore::flush() {
     // ensure consistent state before writing Toc entry
     flushDataHandles();
 
-    size_t out = archivedFields_;
+    size_t out      = archivedFields_;
     archivedFields_ = 0;
 
     return out;
@@ -157,15 +151,18 @@ void TocStore::remove(const eckit::URI& uri, std::ostream& logAlways, std::ostre
     if (path.isDir()) {
         logVerbose << "rmdir: ";
         logAlways << path << std::endl;
-        if (doit) path.rmdir(false);
-    } else {
+        if (doit)
+            path.rmdir(false);
+    }
+    else {
         logVerbose << "Unlinking: ";
         logAlways << path << std::endl;
-        if (doit) path.unlink(false);
+        if (doit)
+            path.unlink(false);
     }
 }
 
-eckit::DataHandle* TocStore::getCachedHandle( const eckit::PathName &path ) const {
+eckit::DataHandle* TocStore::getCachedHandle(const eckit::PathName& path) const {
     std::lock_guard lock(handlesMutex_);
     if (auto j = handles_.find(path); j != handles_.end()) {
         return j->second.get();
@@ -181,59 +178,56 @@ void TocStore::closeDataHandles() {
     handles_.clear();
 }
 
-std::unique_ptr<eckit::DataHandle> TocStore::createFileHandle(const eckit::PathName &path) {
+std::unique_ptr<eckit::DataHandle> TocStore::createFileHandle(const eckit::PathName& path) {
 
     static size_t sizeBuffer = eckit::Resource<unsigned long>("fdbBufferSize", 64 * 1024 * 1024);
 
-    if(stripeLustre()) {
+    if (stripeLustre()) {
 
-        LOG_DEBUG_LIB(LibFdb5) << "Creating LustreFileHandle<FDBFileHandle> to " << path
-                                     << " buffer size " << sizeBuffer
-                                     << std::endl;
+        LOG_DEBUG_LIB(LibFdb5) << "Creating LustreFileHandle<FDBFileHandle> to " << path << " buffer size "
+                               << sizeBuffer << std::endl;
 
         return std::make_unique<LustreFileHandle<FDBFileHandle>>(path, sizeBuffer, stripeDataLustreSettings());
     }
 
-    LOG_DEBUG_LIB(LibFdb5) << "Creating FDBFileHandle to " << path
-                                 << " with buffer of " << eckit::Bytes(sizeBuffer)
-                                 << std::endl;
+    LOG_DEBUG_LIB(LibFdb5) << "Creating FDBFileHandle to " << path << " with buffer of " << eckit::Bytes(sizeBuffer)
+                           << std::endl;
 
     return std::make_unique<FDBFileHandle>(path, sizeBuffer);
 }
 
-std::unique_ptr<eckit::DataHandle> TocStore::createAsyncHandle(const eckit::PathName &path) {
+std::unique_ptr<eckit::DataHandle> TocStore::createAsyncHandle(const eckit::PathName& path) {
 
     static size_t nbBuffers  = eckit::Resource<unsigned long>("fdbNbAsyncBuffers", 4);
     static size_t sizeBuffer = eckit::Resource<unsigned long>("fdbSizeAsyncBuffer", 64 * 1024 * 1024);
 
-    if(stripeLustre()) {
+    if (stripeLustre()) {
 
-        LOG_DEBUG_LIB(LibFdb5) << "Creating LustreFileHandle<AIOHandle> to " << path
-                                     << " with " << nbBuffers
-                                     << " buffer each with " << eckit::Bytes(sizeBuffer)
-                                     << std::endl;
+        LOG_DEBUG_LIB(LibFdb5) << "Creating LustreFileHandle<AIOHandle> to " << path << " with " << nbBuffers
+                               << " buffer each with " << eckit::Bytes(sizeBuffer) << std::endl;
 
-        return std::make_unique<LustreFileHandle<eckit::AIOHandle>>(path, nbBuffers, sizeBuffer, stripeDataLustreSettings());
+        return std::make_unique<LustreFileHandle<eckit::AIOHandle>>(path, nbBuffers, sizeBuffer,
+                                                                    stripeDataLustreSettings());
     }
 
     return std::make_unique<eckit::AIOHandle>(path, nbBuffers, sizeBuffer);
 }
 
-std::unique_ptr<eckit::DataHandle> TocStore::createDataHandle(const eckit::PathName &path) {
+std::unique_ptr<eckit::DataHandle> TocStore::createDataHandle(const eckit::PathName& path) {
 
     static bool fdbWriteToNull = eckit::Resource<bool>("fdbWriteToNull;$FDB_WRITE_TO_NULL", false);
-    if(fdbWriteToNull) {
+    if (fdbWriteToNull) {
         return std::make_unique<eckit::EmptyHandle>();
     }
 
     static bool fdbAsyncWrite = eckit::Resource<bool>("fdbAsyncWrite;$FDB_ASYNC_WRITE", false);
-    if(fdbAsyncWrite)
+    if (fdbAsyncWrite)
         return createAsyncHandle(path);
 
     return createFileHandle(path);
 }
 
-eckit::DataHandle& TocStore::getDataHandle( const eckit::PathName &path ) {
+eckit::DataHandle& TocStore::getDataHandle(const eckit::PathName& path) {
     std::lock_guard lock(handlesMutex_);
     eckit::DataHandle* dh = getCachedHandle(path);
     if (dh) {
@@ -247,20 +241,20 @@ eckit::DataHandle& TocStore::getDataHandle( const eckit::PathName &path ) {
 
 eckit::PathName TocStore::generateDataPath(const Key& key) const {
 
-    eckit::PathName dpath ( directory_ );
-    dpath /=  key.valuesToString();
+    eckit::PathName dpath(directory_);
+    dpath /= key.valuesToString();
     dpath = eckit::PathName::unique(dpath) + ".data";
     return dpath;
 }
 
 eckit::PathName TocStore::getDataPath(const Key& key) const {
     PathStore::const_iterator j = dataPaths_.find(key);
-    if ( j != dataPaths_.end() )
+    if (j != dataPaths_.end())
         return j->second;
 
     eckit::PathName dataPath = generateDataPath(key);
 
-    dataPaths_[ key ] = dataPath;
+    dataPaths_[key] = dataPath;
 
     return dataPath;
 }
@@ -275,7 +269,7 @@ void TocStore::flushDataHandles() {
 bool TocStore::canMoveTo(const Key& key, const Config& config, const eckit::URI& dest) const {
     if (dest.scheme().empty() || dest.scheme() == "toc" || dest.scheme() == "file" || dest.scheme() == "unix") {
         eckit::PathName destPath = dest.path();
-        for (const eckit::PathName& root: StoreRootManager(config).canMoveToRoots(key)) {
+        for (const eckit::PathName& root : StoreRootManager(config).canMoveToRoots(key)) {
             if (root.sameAs(destPath)) {
                 return true;
             }
@@ -320,12 +314,13 @@ std::set<std::string> TocStore::auxFileExtensions() const {
     return extensions;
 }
 
-void TocStore::moveTo(const Key& key, const Config& config, const eckit::URI& dest, eckit::Queue<MoveElement>& queue) const {
+void TocStore::moveTo(const Key& key, const Config& config, const eckit::URI& dest,
+                      eckit::Queue<MoveElement>& queue) const {
     eckit::PathName destPath = dest.path();
 
-    for (const eckit::PathName& root: StoreRootManager(config).canMoveToRoots(key)) {
+    for (const eckit::PathName& root : StoreRootManager(config).canMoveToRoots(key)) {
         if (root.sameAs(destPath)) {
-            eckit::PathName src_db = directory_;
+            eckit::PathName src_db  = directory_;
             eckit::PathName dest_db = destPath / key.valuesToString();
 
             dest_db.mkdir();
@@ -333,9 +328,10 @@ void TocStore::moveTo(const Key& key, const Config& config, const eckit::URI& de
             struct dirent* dp;
             std::multimap<long, FileCopy*, std::greater<long>> files;
             while ((dp = ::readdir(dirp)) != NULL) {
-                if (strstr( dp->d_name, ".data")) {
+                if (strstr(dp->d_name, ".data")) {
                     eckit::PathName file(src_db / dp->d_name);
-                    if ((file.extension() == ".data") || auxFileExtensions_.find(file.extension()) != auxFileExtensions_.end()) {
+                    if ((file.extension() == ".data") ||
+                        auxFileExtensions_.find(file.extension()) != auxFileExtensions_.end()) {
                         struct stat fileStat;
                         SYSCALL(::stat(file.asString().c_str(), &fileStat));
                         files.emplace(fileStat.st_size, new FileCopy(src_db.path(), dest_db, dp->d_name));
@@ -358,7 +354,7 @@ void TocStore::remove(const Key& key) const {
     DIR* dirp = ::opendir(src_db.asString().c_str());
     struct dirent* dp;
     while ((dp = ::readdir(dirp)) != NULL) {
-        if (strstr( dp->d_name, ".data")) {
+        if (strstr(dp->d_name, ".data")) {
             eckit::PathName dataFile = src_db / dp->d_name;
             LOG_DEBUG_LIB(LibFdb5) << "Removing " << dataFile << std::endl;
             dataFile.unlink(false);
@@ -367,7 +363,7 @@ void TocStore::remove(const Key& key) const {
     closedir(dirp);
 }
 
-void TocStore::print(std::ostream &out) const {
+void TocStore::print(std::ostream& out) const {
     out << "TocStore(" << directory_ << ")";
 }
 
@@ -375,4 +371,4 @@ static StoreBuilder<TocStore> builder("file");
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
