@@ -18,10 +18,10 @@
 #include "eckit/option/SimpleOption.h"
 #include "eckit/thread/ThreadPool.h"
 
-#include "fdb5/tools/FDBVisitTool.h"
+#include "fdb5/LibFdb5.h"
 #include "fdb5/api/FDB.h"
 #include "fdb5/api/helpers/FDBToolRequest.h"
-#include "fdb5/LibFdb5.h"
+#include "fdb5/tools/FDBVisitTool.h"
 
 #define MAX_THREADS 256
 
@@ -35,26 +35,25 @@ namespace fdb5::tools {
 
 struct fdb_moveiterator_t {
 public:
+
     fdb_moveiterator_t(fdb5::MoveIterator&& iter) : iter_(std::move(iter)) {}
 
-    bool next(fdb5::MoveElement& elem) {
-        return iter_.next(elem); }
+    bool next(fdb5::MoveElement& elem) { return iter_.next(elem); }
 
 private:
+
     fdb5::MoveIterator iter_;
 };
 
 
 class MoveProducer : public eckit::distributed::Producer {
-public: // methods
+public:  // methods
 
-    MoveProducer(eckit::distributed::Transport &transport,
-                 const Config& config,
-                 const std::vector<fdb5::FDBToolRequest>& requests,
-                 const eckit::option::CmdArgs &args) :
+    MoveProducer(eckit::distributed::Transport& transport, const Config& config,
+                 const std::vector<fdb5::FDBToolRequest>& requests, const eckit::option::CmdArgs& args) :
         eckit::distributed::Producer(transport), fdb_(config), keep_(false), removeDelay_(0) {
 
-        keep_ = args.getBool("keep", false);
+        keep_        = args.getBool("keep", false);
         removeDelay_ = args.getInt("delay", 0);
 
         eckit::URI destination;
@@ -63,12 +62,13 @@ public: // methods
             std::stringstream ss;
             ss << "No destination root specified.";
             throw UserError(ss.str(), Here());
-        } else {
+        }
+        else {
             destination = eckit::URI(dest);
         }
 
         fdb5::FDBToolRequest request = metkit::mars::MarsRequest();
-        size_t count = 0;
+        size_t count                 = 0;
         for (const FDBToolRequest& toolReq : requests) {
             if (count) {
                 std::stringstream ss;
@@ -84,13 +84,14 @@ public: // methods
 
             // check that the request is only referring a single DB - no ranges of values
             const metkit::mars::MarsRequest& marsReq = toolReq.request();
-            std::vector<std::string> params = marsReq.params();
-            for (const std::string& param: params) {
+            std::vector<std::string> params          = marsReq.params();
+            for (const std::string& param : params) {
                 const std::vector<std::string>& values = marsReq.values(param);
 
                 if (values.size() != 1) {
                     std::stringstream ss;
-                    ss << "Move requires a single value for each parameter in the request." << std::endl << "Parameter " << param << "=" << values << " not supported." << std::endl;
+                    ss << "Move requires a single value for each parameter in the request." << std::endl
+                       << "Parameter " << param << "=" << values << " not supported." << std::endl;
                     throw eckit::UserError(ss.str(), Here());
                 }
             }
@@ -100,12 +101,14 @@ public: // methods
             StatsElement se;
             if (!it.next(se)) {
                 std::stringstream ss;
-                ss << "Request " << toolReq << " does not matches with an existing database. Please specify a single database." << std::endl;
+                ss << "Request " << toolReq
+                   << " does not matches with an existing database. Please specify a single database." << std::endl;
                 throw eckit::UserError(ss.str(), Here());
             }
             if (it.next(se)) {
                 std::stringstream ss;
-                ss << "Request " << toolReq << " matches with more than one existing database. Please specify a single database." << std::endl;
+                ss << "Request " << toolReq
+                   << " matches with more than one existing database. Please specify a single database." << std::endl;
                 throw eckit::UserError(ss.str(), Here());
             }
 
@@ -126,7 +129,7 @@ public: // methods
     }
     ~MoveProducer() {}
 
-private: // methods
+private:  // methods
 
     virtual bool produce(eckit::distributed::Message& message) {
         ASSERT(moveIterator_);
@@ -163,9 +166,9 @@ private: // methods
         }
     }
 
-    void messageFromWorker( eckit::distributed::Message& message, int worker) const {}
+    void messageFromWorker(eckit::distributed::Message& message, int worker) const {}
 
-private: // attributes
+private:  // attributes
 
     fdb5::FDB fdb_;
     fdb5::MoveElement last_;
@@ -174,19 +177,18 @@ private: // attributes
 
     bool keep_;
     int removeDelay_;
-
 };
 
 
 class MoveWorker : public eckit::distributed::Consumer {
 
-public: // methods
+public:  // methods
 
-    MoveWorker(eckit::distributed::Transport& transport, const eckit::option::CmdArgs &args) :
+    MoveWorker(eckit::distributed::Transport& transport, const eckit::option::CmdArgs& args) :
         eckit::distributed::Consumer(transport), count_(0) {}
     ~MoveWorker() {}
 
-protected: // members
+protected:  // members
 
     void consume(eckit::distributed::Message& message) override {
         fdb5::FileCopy fileCopy(message);
@@ -195,22 +197,18 @@ protected: // members
         count_++;
         fileCopy.execute();
     }
-    void finalise() override {
-        transport_.synchronise();
-    };
+    void finalise() override { transport_.synchronise(); };
 
     // virtual void getNextMessage(eckit::Message& message) const;
     // virtual void failure(eckit::Message &message);
-    void shutdown(eckit::distributed::Message & message) override {
+    void shutdown(eckit::distributed::Message& message) override {
         LOG_DEBUG_LIB(LibFdb5) << "Shuting down MoveWorker..." << std::endl;
         message << count_;
     }
 
-    void getNextMessage(eckit::distributed::Message & message) const override {
-        getNextWorkMessage(message);
-    }
+    void getNextMessage(eckit::distributed::Message& message) const override { getNextWorkMessage(message); }
 
-private: // attributes
+private:  // attributes
 
     size_t count_;
 };
@@ -218,22 +216,19 @@ private: // attributes
 //----------------------------------------------------------------------------------------------------------------------
 
 class MoveLoner : public eckit::distributed::Actor {
-public: // methods
+public:  // methods
 
-    MoveLoner(eckit::distributed::Transport &transport,
-              eckit::distributed::Producer* producer,
-              eckit::distributed::Consumer* consumer,
-              size_t numThreads=1) :
-        eckit::distributed::Actor(transport),
-        producer_(producer), consumer_(consumer), numThreads_(numThreads) {}
+    MoveLoner(eckit::distributed::Transport& transport, eckit::distributed::Producer* producer,
+              eckit::distributed::Consumer* consumer, size_t numThreads = 1) :
+        eckit::distributed::Actor(transport), producer_(producer), consumer_(consumer), numThreads_(numThreads) {}
 
-private: // methods
+private:  // methods
 
     virtual void run() {
         eckit::distributed::Message message;
 
-        eckit::distributed::Producer &producer = *producer_;
-        eckit::distributed::Consumer &consumer = *consumer_;
+        eckit::distributed::Producer& producer = *producer_;
+        eckit::distributed::Consumer& consumer = *consumer_;
 
         eckit::ThreadPool pool("move", numThreads_);
 
@@ -241,7 +236,8 @@ private: // methods
             message.rewind();
             try {
                 pool.push(new FileCopy(message));
-            } catch (eckit::Exception &e) {
+            }
+            catch (eckit::Exception& e) {
                 eckit::Log::error() << e.what() << std::endl;
                 consumer.failure(message);
             }
@@ -256,14 +252,14 @@ private: // methods
     }
 
     virtual void finalise() {
-        eckit::distributed::Producer &producer = *producer_;
-        eckit::distributed::Consumer &consumer = *consumer_;
+        eckit::distributed::Producer& producer = *producer_;
+        eckit::distributed::Consumer& consumer = *consumer_;
 
         consumer.finalise();
         producer.finalise();
     }
 
-private: // members
+private:  // members
 
     std::unique_ptr<eckit::distributed::Producer> producer_;
     std::unique_ptr<eckit::distributed::Consumer> consumer_;
@@ -274,24 +270,23 @@ private: // members
 
 
 class FDBMove : public FDBVisitTool {
-public: // methods
+public:  // methods
 
-    FDBMove(int argc, char **argv);
+    FDBMove(int argc, char** argv);
     ~FDBMove() override;
 
-private: // methods
+private:  // methods
 
     void execute(const CmdArgs& args) override;
-    void init(const CmdArgs &args) override;
+    void init(const CmdArgs& args) override;
 
-private: // members
+private:  // members
 
     std::unique_ptr<eckit::distributed::Transport> transport_;
     int threads_;
 };
 
-FDBMove::FDBMove(int argc, char **argv) :
-    FDBVisitTool(argc, argv, "class,expver,stream,date,time") {
+FDBMove::FDBMove(int argc, char** argv) : FDBVisitTool(argc, argv, "class,expver,stream,date,time") {
 
     options_.push_back(new SimpleOption<std::string>("dest", "Destination root"));
     options_.push_back(new SimpleOption<bool>("keep", "Keep source DB"));
@@ -323,15 +318,16 @@ void FDBMove::execute(const CmdArgs& args) {
                 throw UserError(ss.str(), Here());
             }
 
-            actor.reset(new MoveLoner(*transport,
-                            new MoveProducer(*transport, config(args), requests("read"), args),
-                            new MoveWorker(*transport, args),
-                            threads_)); // do it all actor :)
-        } else {
+            actor.reset(new MoveLoner(*transport, new MoveProducer(*transport, config(args), requests("read"), args),
+                                      new MoveWorker(*transport, args),
+                                      threads_));  // do it all actor :)
+        }
+        else {
             if (transport->producer()) {
-                actor.reset(new MoveProducer(*transport, config(args), requests("read"), args)); // work dispatcher
-            } else {
-                actor.reset(new MoveWorker(*transport, args)); // worker
+                actor.reset(new MoveProducer(*transport, config(args), requests("read"), args));  // work dispatcher
+            }
+            else {
+                actor.reset(new MoveWorker(*transport, args));  // worker
             }
         }
 
@@ -345,14 +341,13 @@ void FDBMove::execute(const CmdArgs& args) {
         //                    << ": "
         //                    << eckit::system::ResourceUsage()
         //                    << std::endl;
-
-    } catch (std::exception &e) {
+    }
+    catch (std::exception& e) {
         eckit::Log::info()
-                        //    << eckit::TimeStamp()
-                        //    << " "
-                        //    << title
-                           << " EXCEPTION: "
-                           << e.what() << std::endl;
+            //    << eckit::TimeStamp()
+            //    << " "
+            //    << title
+            << " EXCEPTION: " << e.what() << std::endl;
         transport->abort();
         throw;
     }
@@ -360,9 +355,9 @@ void FDBMove::execute(const CmdArgs& args) {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5::tools
+}  // namespace fdb5::tools
 
-int main(int argc, char **argv) {
+int main(int argc, char** argv) {
     fdb5::tools::FDBMove app(argc, argv);
     return app.start();
 }
