@@ -10,8 +10,8 @@
 
 #include <memory>
 
-#include "eckit/option/CmdArgs.h"
 #include "eckit/log/Log.h"
+#include "eckit/option/CmdArgs.h"
 
 #include "fdb5/LibFdb5.h"
 #include "fdb5/config/Config.h"
@@ -26,19 +26,20 @@ namespace tools {
 //----------------------------------------------------------------------------------------------------------------------
 
 class FdbSchema : public FDBTool {
-    virtual void execute(const eckit::option::CmdArgs &args);
-    virtual void usage(const std::string &tool) const;
+    virtual void execute(const eckit::option::CmdArgs& args);
+    virtual void usage(const std::string& tool) const;
+
 public:
-    FdbSchema(int argc, char **argv): FDBTool(argc, argv) {}
+
+    FdbSchema(int argc, char** argv) : FDBTool(argc, argv) {}
 };
 
-void FdbSchema::usage(const std::string &tool) const {
-    eckit::Log::info() << std::endl
-                       << "Usage: " << tool << " [shema] ..." << std::endl;
+void FdbSchema::usage(const std::string& tool) const {
+    eckit::Log::info() << std::endl << "Usage: " << tool << " [shema] ..." << std::endl;
     FDBTool::usage(tool);
 }
 
-void FdbSchema:: execute(const eckit::option::CmdArgs &args) {
+void FdbSchema::execute(const eckit::option::CmdArgs& args) {
 
 
     // With no arguments, provide the current master configuration schema (i.e. that selected by FDB_HOME)
@@ -46,7 +47,8 @@ void FdbSchema:: execute(const eckit::option::CmdArgs &args) {
     if (args.count() == 0 || args.has("config")) {
         Config conf = config(args);
         conf.schema().dump(Log::info());
-    } else {
+    }
+    else {
 
         // If the argument specifies a schema file, then examine that. Otherwise load the DB which is
         // pointed to, and return the schema presented by that.
@@ -56,13 +58,15 @@ void FdbSchema:: execute(const eckit::option::CmdArgs &args) {
             eckit::PathName path(args(i));
 
             if (path.isDir()) {
-                std::unique_ptr<DB> db = DB::buildReader(eckit::URI("toc", path));
-                ASSERT(db->open());
-                db->schema().dump(Log::info());
-            } else {
-                Schema schema;
-                schema.load(args(i));
-                schema.dump(Log::info());
+                std::unique_ptr<CatalogueReader> cat =
+                    CatalogueReaderFactory::instance().build(eckit::URI("toc", path), fdb5::Config());
+                ASSERT(cat->open());
+                cat->schema().dump(Log::info());
+            }
+            else {
+                Schema* schema = new Schema(args(i));
+                schema->dump(Log::info());
+                delete schema;
             }
         }
     }
@@ -70,11 +74,10 @@ void FdbSchema:: execute(const eckit::option::CmdArgs &args) {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace tools
-} // namespace fdb5
+}  // namespace tools
+}  // namespace fdb5
 
-int main(int argc, char **argv) {
+int main(int argc, char** argv) {
     fdb5::tools::FdbSchema app(argc, argv);
     return app.start();
 }
-
