@@ -25,9 +25,9 @@ class Notifier;
 
 namespace metkit {
 namespace mars {
-  class MarsRequest;
-}
+class MarsRequest;
 }
+}  // namespace metkit
 
 namespace fdb5 {
 
@@ -38,48 +38,44 @@ class Notifier;
 
 class Type : private eckit::NonCopyable {
 
-public: // methods
+public:  // methods
 
-    Type(const std::string &name, const std::string& type, const std::string& alias = "");
+    Type(const std::string& name, const std::string& type, const std::string& alias = "");
 
     virtual ~Type() = default;
 
     const std::string& alias() const;
-    
-    virtual std::string tidy(const std::string &value) const ;
 
-    virtual std::string toKey(const std::string &value) const ;
+    virtual std::string tidy(const std::string& value) const;
 
-    virtual void getValues(const metkit::mars::MarsRequest &request,
-                           const std::string &keyword,
-                           eckit::StringList &values,
-                           const Notifier &wind,
-                           const CatalogueReader* cat) const;
+    virtual std::string toKey(const std::string& value) const;
+
+    virtual void getValues(const metkit::mars::MarsRequest& request, const std::string& keyword,
+                           eckit::StringList& values, const Notifier& wind, const CatalogueReader* cat) const;
 
     virtual bool match(const std::string& keyword, const std::string& value1, const std::string& value2) const;
 
-    friend std::ostream &operator<<(std::ostream &s, const Type &x);
+    friend std::ostream& operator<<(std::ostream& s, const Type& x);
 
-public: // class methods
+public:  // class methods
 
-    static const Type &lookup(const std::string &keyword);
+    static const Type& lookup(const std::string& keyword);
 
-    const std::string &type() const;
+    const std::string& type() const;
 
-private: // methods
+private:  // methods
 
-    virtual void print( std::ostream &out ) const = 0;
+    virtual void print(std::ostream& out) const = 0;
 
-protected: // members
+protected:  // members
 
     std::string name_;
     std::string type_;
     std::string alias_;
-
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
 
 #endif
