@@ -11,29 +11,24 @@
 #include <iomanip>
 #include <sstream>
 
-#include "eckit/utils/Translator.h"
 #include "eckit/utils/StringTools.h"
+#include "eckit/utils/Translator.h"
 
 #include "eckit/types/Date.h"
 
-#include "fdb5/types/TypesFactory.h"
 #include "fdb5/types/TypeExpver.h"
+#include "fdb5/types/TypesFactory.h"
 
 namespace fdb5 {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-TypeExpver::TypeExpver(const std::string &name, const std::string &type) :
-    Type(name, type) {
-}
+TypeExpver::TypeExpver(const std::string& name, const std::string& type) : Type(name, type) {}
 
-TypeExpver::~TypeExpver() {
-}
+TypeExpver::~TypeExpver() {}
 
 
-std::string TypeExpver::tidy(const std::string&,
-                             const std::string& value) const {
-
+std::string TypeExpver::tidy(const std::string& value) const {
 
     std::ostringstream oss;
     oss << std::setfill('0') << std::setw(4) << eckit::StringTools::trim(value);
@@ -41,7 +36,7 @@ std::string TypeExpver::tidy(const std::string&,
 }
 
 
-void TypeExpver::print(std::ostream &out) const {
+void TypeExpver::print(std::ostream& out) const {
     out << "TypeExpver[name=" << name_ << "]";
 }
 
@@ -49,4 +44,4 @@ static TypeBuilder<TypeExpver> type("Expver");
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
