@@ -15,19 +15,16 @@
 #include "eckit/types/Date.h"
 #include "metkit/mars/MarsRequest.h"
 
-#include "fdb5/types/TypesFactory.h"
 #include "fdb5/types/TypeTime.h"
+#include "fdb5/types/TypesFactory.h"
 
 namespace fdb5 {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-TypeTime::TypeTime(const std::string &name, const std::string &type) :
-    Type(name, type) {
-}
+TypeTime::TypeTime(const std::string& name, const std::string& type) : Type(name, type) {}
 
-TypeTime::~TypeTime() {
-}
+TypeTime::~TypeTime() {}
 
 std::string TypeTime::tidy(const std::string& value) const {
 
@@ -37,7 +34,7 @@ std::string TypeTime::tidy(const std::string& value) const {
 std::string TypeTime::toKey(const std::string& value) const {
 
     // if value just contains a digit, add a leading zero to be compliant with eckit::Time
-    std::string t = value.size() < 2 ? "0"+value : value;
+    std::string t = value.size() < 2 ? "0" + value : value;
     eckit::Time time(t);
 
     std::ostringstream oss;
@@ -45,7 +42,7 @@ std::string TypeTime::toKey(const std::string& value) const {
     return oss.str();
 }
 
-void TypeTime::print(std::ostream &out) const {
+void TypeTime::print(std::ostream& out) const {
     out << "TypeTime[name=" << name_ << "]";
 }
 
@@ -53,4 +50,4 @@ static TypeBuilder<TypeTime> type("Time");
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
