@@ -12,56 +12,56 @@
 #include <memory>
 
 #include "eckit/config/Resource.h"
-#include "eckit/testing/Test.h"
-#include "eckit/filesystem/URI.h"
+#include "eckit/config/YAMLConfiguration.h"
 #include "eckit/filesystem/PathName.h"
-#include "eckit/filesystem/TmpFile.h"
 #include "eckit/filesystem/TmpDir.h"
+#include "eckit/filesystem/TmpFile.h"
+#include "eckit/filesystem/URI.h"
 #include "eckit/io/FileHandle.h"
 #include "eckit/io/MemoryHandle.h"
-#include "eckit/config/YAMLConfiguration.h"
+#include "eckit/testing/Test.h"
 
 #include "metkit/mars/MarsRequest.h"
 
-#include "fdb5/fdb5_config.h"
-#include "fdb5/config/Config.h"
 #include "fdb5/api/FDB.h"
 #include "fdb5/api/helpers/FDBToolRequest.h"
+#include "fdb5/config/Config.h"
+#include "fdb5/fdb5_config.h"
 
-#include "fdb5/toc/TocCatalogueWriter.h"
 #include "fdb5/toc/TocCatalogueReader.h"
+#include "fdb5/toc/TocCatalogueWriter.h"
 
-#include "fdb5/daos/DaosSession.h"
-#include "fdb5/daos/DaosPool.h"
 #include "fdb5/daos/DaosArrayPartHandle.h"
+#include "fdb5/daos/DaosPool.h"
+#include "fdb5/daos/DaosSession.h"
 
-#include "fdb5/daos/DaosStore.h"
-#include "fdb5/daos/DaosFieldLocation.h"
 #include "fdb5/daos/DaosException.h"
+#include "fdb5/daos/DaosFieldLocation.h"
+#include "fdb5/daos/DaosStore.h"
 
 using namespace eckit::testing;
 using namespace eckit;
 
 namespace {
-    void deldir(eckit::PathName& p) {
-        if (!p.exists()) {
-            return;
-        }
+void deldir(eckit::PathName& p) {
+    if (!p.exists()) {
+        return;
+    }
 
-        std::vector<eckit::PathName> files;
-        std::vector<eckit::PathName> dirs;
-        p.children(files, dirs);
+    std::vector<eckit::PathName> files;
+    std::vector<eckit::PathName> dirs;
+    p.children(files, dirs);
 
-        for (auto& f : files) {
-            f.unlink();
-        }
-        for (auto& d : dirs) {
-            deldir(d);
-        }
+    for (auto& f : files) {
+        f.unlink();
+    }
+    for (auto& d : dirs) {
+        deldir(d);
+    }
 
-        p.rmdir();
-    };
-}
+    p.rmdir();
+};
+}  // namespace
 
 #ifdef fdb5_HAVE_DUMMY_DAOS
 eckit::TmpDir& tmp_dummy_daos_root() {
@@ -85,16 +85,17 @@ eckit::PathName& store_tests_tmp_root() {
 namespace fdb {
 namespace test {
 
-CASE( "Setup" ) {
+CASE("Setup") {
 
 #ifdef fdb5_HAVE_DUMMY_DAOS
     tmp_dummy_daos_root().mkdir();
     ::setenv("DUMMY_DAOS_DATA_ROOT", tmp_dummy_daos_root().path().c_str(), 1);
 #endif
 
-    // ensure fdb root directory exists. If not, then that root is 
+    // ensure fdb root directory exists. If not, then that root is
     // registered as non existing and Store tests fail.
-    if (store_tests_tmp_root().exists()) deldir(store_tests_tmp_root());
+    if (store_tests_tmp_root().exists())
+        deldir(store_tests_tmp_root());
     store_tests_tmp_root().mkdir();
     ::setenv("FDB_ROOT_DIRECTORY", store_tests_tmp_root().path().c_str(), 1);
 
@@ -113,7 +114,6 @@ CASE( "Setup" ) {
     // LibFdb5::instance().defaultConfig().schema() is called
     // due to no specified schema file (e.g. in Key::registry())
     ::setenv("FDB_SCHEMA_FILE", schema_file().path().c_str(), 1);
-
 }
 
 CASE("DaosStore tests") {
@@ -125,9 +125,7 @@ CASE("DaosStore tests") {
     std::string pool_name{"fdb_pool"};
 #else
     std::string pool_name;
-    pool_name = eckit::Resource<std::string>(
-        "fdbDaosTestPool;$FDB_DAOS_TEST_POOL", pool_name
-    );
+    pool_name = eckit::Resource<std::string>("fdbDaosTestPool;$FDB_DAOS_TEST_POOL", pool_name);
     EXPECT(pool_name.length() > 0);
 #endif
 
@@ -135,23 +133,18 @@ CASE("DaosStore tests") {
 
     fdb5::UUID pool_uuid;
     {
-        fdb5::DaosManager::instance().configure(
-            eckit::LocalConfiguration(YAMLConfiguration(
-                "container_oids_per_alloc: " + std::to_string(container_oids_per_alloc)
-            ))
-        );
+        fdb5::DaosManager::instance().configure(eckit::LocalConfiguration(
+            YAMLConfiguration("container_oids_per_alloc: " + std::to_string(container_oids_per_alloc))));
         fdb5::DaosSession s{};
 #ifdef fdb5_HAVE_DAOS_ADMIN
         fdb5::DaosPool& pool = s.createPool(pool_name);
 #else
-  #ifdef fdb5_HAVE_DUMMY_DAOS
+#ifdef fdb5_HAVE_DUMMY_DAOS
         std::string pool_uuid_str{"00000000-0000-0000-0000-000000000003"};
         (tmp_dummy_daos_root() / pool_uuid_str).mkdir();
-        ::symlink(
-            (tmp_dummy_daos_root() / pool_uuid_str).path().c_str(), 
-            (tmp_dummy_daos_root() / pool_name).path().c_str()
-        );
-  #endif
+        ::symlink((tmp_dummy_daos_root() / pool_uuid_str).path().c_str(),
+                  (tmp_dummy_daos_root() / pool_name).path().c_str());
+#endif
         fdb5::DaosPool& pool = s.getPool(pool_name);
 #endif
         pool_uuid = pool.uuid();
@@ -162,13 +155,17 @@ CASE("DaosStore tests") {
         std::string config_str{
             "spaces:\n"
             "- roots:\n"
-            "  - path: " + store_tests_tmp_root().asString() + "\n"
+            "  - path: " +
+            store_tests_tmp_root().asString() +
+            "\n"
             "daos:\n"
             "  store:\n"
-            "    pool: " + pool_name + "\n"
+            "    pool: " +
+            pool_name +
+            "\n"
             "  client:\n"
-            "    container_oids_per_alloc: " + std::to_string(container_oids_per_alloc)
-        };
+            "    container_oids_per_alloc: " +
+            std::to_string(container_oids_per_alloc)};
 
         fdb5::Config config{YAMLConfiguration(config_str)};
 
@@ -196,7 +193,7 @@ CASE("DaosStore tests") {
         std::cout << "Read location: " << field.location() << std::endl;
         std::unique_ptr<eckit::DataHandle> dh(store.retrieve(field));
         EXPECT(dynamic_cast<fdb5::DaosArrayPartHandle*>(dh.get()));
-    
+
         eckit::MemoryHandle mh;
         dh->copyTo(mh);
         EXPECT(mh.size() == eckit::Length(sizeof(data)));
@@ -219,7 +216,6 @@ CASE("DaosStore tests") {
         /// @todo: check that the URI is properly produced
 
         /// @todo: assert a new DaosSession shows newly configured container_oids_per_alloc
-
     }
 
     SECTION("with POSIX Catalogue") {
@@ -229,14 +225,20 @@ CASE("DaosStore tests") {
         std::string config_str{
             "spaces:\n"
             "- roots:\n"
-            "  - path: " + store_tests_tmp_root().asString() + "\n"
-            "schema : " + schema_file().path() + "\n"
+            "  - path: " +
+            store_tests_tmp_root().asString() +
+            "\n"
+            "schema : " +
+            schema_file().path() +
+            "\n"
             "daos:\n"
             "  store:\n"
-            "    pool: " + pool_name + "\n"
+            "    pool: " +
+            pool_name +
+            "\n"
             "  client:\n"
-            "    container_oids_per_alloc: " + std::to_string(container_oids_per_alloc)
-        };
+            "    container_oids_per_alloc: " +
+            std::to_string(container_oids_per_alloc)};
 
         fdb5::Config config{YAMLConfiguration(config_str)};
 
@@ -269,7 +271,7 @@ CASE("DaosStore tests") {
             fdb5::Catalogue& cat = static_cast<fdb5::Catalogue&>(tcat);
             cat.deselectIndex();
             cat.selectIndex(index_key);
-            //const fdb5::Index& idx = tcat.currentIndex();
+            // const fdb5::Index& idx = tcat.currentIndex();
             static_cast<fdb5::CatalogueWriter&>(tcat).archive(index_key, field_key, std::move(loc));
 
             /// flush store before flushing catalogue
@@ -291,7 +293,7 @@ CASE("DaosStore tests") {
 
         std::unique_ptr<eckit::DataHandle> dh(store.retrieve(field));
         EXPECT(dynamic_cast<fdb5::DaosArrayPartHandle*>(dh.get()));
-    
+
         eckit::MemoryHandle mh;
         dh->copyTo(mh);
         EXPECT(mh.size() == eckit::Length(sizeof(data)));
@@ -313,7 +315,7 @@ CASE("DaosStore tests") {
 
         {
             fdb5::TocCatalogueWriter tcat{db_key, config};
-            fdb5::Catalogue& cat = static_cast<fdb5::Catalogue&>(tcat);
+            fdb5::Catalogue& cat        = static_cast<fdb5::Catalogue&>(tcat);
             metkit::mars::MarsRequest r = db_key.request("retrieve");
             std::unique_ptr<fdb5::WipeVisitor> wv(cat.wipeVisitor(store, r, out, true, false, false));
             cat.visitEntries(*wv, false);
@@ -331,17 +333,23 @@ CASE("DaosStore tests") {
         std::string config_str{
             "spaces:\n"
             "- roots:\n"
-            "  - path: " + store_tests_tmp_root().asString() + "\n"
+            "  - path: " +
+            store_tests_tmp_root().asString() +
+            "\n"
             "type: local\n"
-            "schema : " + schema_file().path() + "\n"
+            "schema : " +
+            schema_file().path() +
+            "\n"
             "engine: toc\n"
             "store: daos\n"
             "daos:\n"
             "  store:\n"
-            "    pool: " + pool_name + "\n"
+            "    pool: " +
+            pool_name +
+            "\n"
             "  client:\n"
-            "    container_oids_per_alloc: " + std::to_string(container_oids_per_alloc_small)
-        };
+            "    container_oids_per_alloc: " +
+            std::to_string(container_oids_per_alloc_small)};
 
         fdb5::Config config{YAMLConfiguration(config_str)};
 
@@ -351,21 +359,9 @@ CASE("DaosStore tests") {
         fdb5::Key db_key({{"a", "1"}, {"b", "2"}});
         fdb5::Key index_key({{"a", "1"}, {"b", "2"}, {"c", "3"}, {"d", "4"}});
 
-        fdb5::FDBToolRequest full_req{
-            request_key.request("retrieve"), 
-            false, 
-            std::vector<std::string>{"a", "b"}
-        };
-        fdb5::FDBToolRequest index_req{
-            index_key.request("retrieve"), 
-            false, 
-            std::vector<std::string>{"a", "b"}
-        };
-        fdb5::FDBToolRequest db_req{
-            db_key.request("retrieve"), 
-            false, 
-            std::vector<std::string>{"a", "b"}
-        };
+        fdb5::FDBToolRequest full_req{request_key.request("retrieve"), false, std::vector<std::string>{"a", "b"}};
+        fdb5::FDBToolRequest index_req{index_key.request("retrieve"), false, std::vector<std::string>{"a", "b"}};
+        fdb5::FDBToolRequest db_req{db_key.request("retrieve"), false, std::vector<std::string>{"a", "b"}};
 
         // initialise store
 
@@ -384,7 +380,7 @@ CASE("DaosStore tests") {
 
         count = 0;
         while (listObject.next(info)) {
-            info.print(std::cout, true, true, false," ");
+            info.print(std::cout, true, true, false, " ");
             std::cout << std::endl;
             ++count;
         }
@@ -394,7 +390,8 @@ CASE("DaosStore tests") {
 
         char data[] = "test";
 
-        /// @todo: here, DaosManager is being reconfigured with identical config, and it happens again multiple times below.
+        /// @todo: here, DaosManager is being reconfigured with identical config, and it happens again multiple times
+        /// below.
         //   Should this be avoided?
         fdb.archive(request_key, data, sizeof(data));
 
@@ -404,7 +401,7 @@ CASE("DaosStore tests") {
 
         metkit::mars::MarsRequest r = request_key.request("retrieve");
         std::unique_ptr<eckit::DataHandle> dh(fdb.retrieve(r));
-    
+
         eckit::MemoryHandle mh;
         dh->copyTo(mh);
         EXPECT(mh.size() == eckit::Length(sizeof(data)));
@@ -417,25 +414,28 @@ CASE("DaosStore tests") {
         // dry run attempt to wipe with too specific request
 
         auto wipeObject = fdb.wipe(full_req);
-        count = 0;
-        while (wipeObject.next(elem)) count++;
+        count           = 0;
+        while (wipeObject.next(elem))
+            count++;
         EXPECT(count == 0);
 
         // dry run wipe index and store unit
         wipeObject = fdb.wipe(index_req);
-        count = 0;
-        while (wipeObject.next(elem)) count++;
+        count      = 0;
+        while (wipeObject.next(elem))
+            count++;
         EXPECT(count > 0);
 
         // dry run wipe database
         wipeObject = fdb.wipe(db_req);
-        count = 0;
-        while (wipeObject.next(elem)) count++;
+        count      = 0;
+        while (wipeObject.next(elem))
+            count++;
         EXPECT(count > 0);
 
         // ensure field still exists
         listObject = fdb.list(full_req);
-        count = 0;
+        count      = 0;
         while (listObject.next(info)) {
             // info.print(std::cout, true, true);
             // std::cout << std::endl;
@@ -445,24 +445,27 @@ CASE("DaosStore tests") {
 
         // attempt to wipe with too specific request
         wipeObject = fdb.wipe(full_req, true);
-        count = 0;
-        while (wipeObject.next(elem)) count++;
+        count      = 0;
+        while (wipeObject.next(elem))
+            count++;
         EXPECT(count == 0);
         /// @todo: really needed?
         fdb.flush();
 
         // wipe index and store unit (and DB container as there is only one index)
         wipeObject = fdb.wipe(index_req, true);
-        count = 0;
-        while (wipeObject.next(elem)) count++;
+        count      = 0;
+        while (wipeObject.next(elem))
+            count++;
         EXPECT(count > 0);
         /// @todo: really needed?
         fdb.flush();
 
         // ensure field does not exist
         listObject = fdb.list(full_req);
-        count = 0;
-        while (listObject.next(info)) count++;
+        count      = 0;
+        while (listObject.next(info))
+            count++;
         EXPECT(count == 0);
 
         /// @todo: ensure index and corresponding container do not exist
@@ -471,7 +474,6 @@ CASE("DaosStore tests") {
         ///   ensure DB still exists with one index
 
         /// @todo: ensure new DaosSession has updated daos client config
-
     }
 
     /// @todo: if doing what's in this section at the end of the previous section reusing the same FDB object,
@@ -483,17 +485,23 @@ CASE("DaosStore tests") {
         std::string config_str{
             "spaces:\n"
             "- roots:\n"
-            "  - path: " + store_tests_tmp_root().asString() + "\n"
+            "  - path: " +
+            store_tests_tmp_root().asString() +
+            "\n"
             "type: local\n"
-            "schema : " + schema_file().path() + "\n"
+            "schema : " +
+            schema_file().path() +
+            "\n"
             "engine: toc\n"
             "store: daos\n"
             "daos:\n"
             "  store:\n"
-            "    pool: " + pool_name + "\n"
+            "    pool: " +
+            pool_name +
+            "\n"
             "  client:\n"
-            "    container_oids_per_alloc: " + std::to_string(container_oids_per_alloc)
-        };
+            "    container_oids_per_alloc: " +
+            std::to_string(container_oids_per_alloc)};
 
         fdb5::Config config{YAMLConfiguration(config_str)};
 
@@ -503,21 +511,9 @@ CASE("DaosStore tests") {
         fdb5::Key db_key({{"a", "1"}, {"b", "2"}});
         fdb5::Key index_key({{"a", "1"}, {"b", "2"}, {"c", "3"}, {"d", "4"}});
 
-        fdb5::FDBToolRequest full_req{
-            request_key.request("retrieve"), 
-            false, 
-            std::vector<std::string>{"a", "b"}
-        };
-        fdb5::FDBToolRequest index_req{
-            index_key.request("retrieve"), 
-            false, 
-            std::vector<std::string>{"a", "b"}
-        };
-        fdb5::FDBToolRequest db_req{
-            db_key.request("retrieve"), 
-            false, 
-            std::vector<std::string>{"a", "b"}
-        };
+        fdb5::FDBToolRequest full_req{request_key.request("retrieve"), false, std::vector<std::string>{"a", "b"}};
+        fdb5::FDBToolRequest index_req{index_key.request("retrieve"), false, std::vector<std::string>{"a", "b"}};
+        fdb5::FDBToolRequest db_req{db_key.request("retrieve"), false, std::vector<std::string>{"a", "b"}};
 
         // initialise store
 
@@ -528,17 +524,18 @@ CASE("DaosStore tests") {
         char data[] = "test";
 
         fdb.archive(request_key, data, sizeof(data));
-        
+
         fdb.flush();
 
         size_t count;
-        
+
         // wipe all database
 
         fdb5::WipeElement elem;
         auto wipeObject = fdb.wipe(db_req, true);
-        count = 0;
-        while (wipeObject.next(elem)) count++;
+        count           = 0;
+        while (wipeObject.next(elem))
+            count++;
         EXPECT(count > 0);
         /// @todo: really needed?
         fdb.flush();
@@ -547,7 +544,7 @@ CASE("DaosStore tests") {
 
         fdb5::ListElement info;
         auto listObject = fdb.list(full_req);
-        count = 0;
+        count           = 0;
         while (listObject.next(info)) {
             // info.print(std::cout, true, true);
             // std::cout << std::endl;
@@ -556,13 +553,12 @@ CASE("DaosStore tests") {
         EXPECT(count == 0);
 
         /// @todo: ensure DB and corresponding cont do not exist
-
     }
 
     // teardown daos
 
 #ifdef fdb5_HAVE_DAOS_ADMIN
-    /// AutoPoolDestroy is not possible here because the pool is 
+    /// AutoPoolDestroy is not possible here because the pool is
     /// created above with an ephemeral session
     fdb5::DaosSession().destroyPool(pool_uuid);
 #else
@@ -570,13 +566,11 @@ CASE("DaosStore tests") {
         if (c == "1:2")
             fdb5::DaosSession().getPool(pool_uuid).destroyContainer(c);
 #endif
-
 }
 
 }  // namespace test
 }  // namespace fdb
 
-int main(int argc, char **argv)
-{
-    return run_tests ( argc, argv );
+int main(int argc, char** argv) {
+    return run_tests(argc, argv);
 }
