@@ -17,24 +17,24 @@
 #include <dirent.h>
 #include <fcntl.h>
 
+#include "eckit/io/AutoCloser.h"
 #include "eckit/io/DataHandle.h"
 #include "eckit/io/MemoryHandle.h"
 #include "eckit/runtime/Main.h"
+#include "eckit/serialisation/FileStream.h"
+#include "eckit/serialisation/MemoryStream.h"
 #include "eckit/types/Types.h"
 #include "eckit/utils/Translator.h"
-#include "eckit/serialisation/MemoryStream.h"
-#include "eckit/serialisation/FileStream.h"
-#include "eckit/io/AutoCloser.h"
 
 #include "metkit/mars/MarsExpension.h"
 #include "metkit/mars/MarsRequest.h"
 #include "metkit/mars/TypeAny.h"
 
-#include "fdb5/database/Key.h"
-#include "fdb5/database/Archiver.h"
-#include "fdb5/database/ArchiveVisitor.h"
 #include "fdb5/api/FDB.h"
 #include "fdb5/api/helpers/FDBToolRequest.h"
+#include "fdb5/database/ArchiveVisitor.h"
+#include "fdb5/database/Archiver.h"
+#include "fdb5/database/Key.h"
 
 #include "eckit/testing/Test.h"
 
@@ -57,48 +57,40 @@ struct FixtureService {
 
     std::vector<std::string> modelParams_;
 
-    FixtureService() : env("environ")
-    {
+    FixtureService() : env("environ") {
         p["class"]  = "rd";
         p["stream"] = "oper";
         p["domain"] = "g";
         p["expver"] = "0001";
-        p["date"] = "20120911";
-        p["time"] = "0000";
-        p["type"] = "fc";
+        p["date"]   = "20120911";
+        p["time"]   = "0000";
+        p["type"]   = "fc";
 
-        modelParams_.push_back( "130.128" );
-        modelParams_.push_back( "138.128" );
+        modelParams_.push_back("130.128");
+        modelParams_.push_back("138.128");
     }
 
-    void write_cycle(fdb5::Archiver& fdb, StringDict& p )
-    {
-        Translator<size_t,std::string> str;
+    void write_cycle(fdb5::Archiver& fdb, StringDict& p) {
+        Translator<size_t, std::string> str;
         std::vector<std::string>::iterator param = modelParams_.begin();
-        for( ; param != modelParams_.end(); ++param )
-        {
+        for (; param != modelParams_.end(); ++param) {
             p["param"] = *param;
 
             p["levtype"] = "pl";
 
-            for( size_t step = 0; step < 12; ++step )
-            {
-                p["step"] = str(step*3);
+            for (size_t step = 0; step < 12; ++step) {
+                p["step"] = str(step * 3);
 
-                for( size_t level = 0; level < 10; ++level )
-                {
-                    p["levelist"] = str(level*100);
+                for (size_t level = 0; level < 10; ++level) {
+                    p["levelist"] = str(level * 100);
 
                     std::ostringstream data;
                     data << "Raining cats and dogs -- "
-                         << " param " << *param
-                         << " step "  << step
-                         << " level " << level
-                         << std::endl;
+                         << " param " << *param << " step " << step << " level " << level << std::endl;
                     std::string data_str = data.str();
 
                     fdb5::Key k{p};
-                    ArchiveVisitor visitor(fdb, k, static_cast<const void *>(data_str.c_str()), data_str.size());
+                    ArchiveVisitor visitor(fdb, k, static_cast<const void*>(data_str.c_str()), data_str.size());
                     fdb.archive(k, visitor);
                 }
             }
@@ -108,24 +100,24 @@ struct FixtureService {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-CASE ( "test_fdb_stepunit_archive" ) {
+CASE("test_fdb_stepunit_archive") {
 
     std::string data_str = "Raining cats and dogs";
 
     fdb5::FDB fdb;
 
     Key key;
-    key.set("class","od");
-    key.set("expver","0001");
-    key.set("type","fc");
-    key.set("stream","oper");
-    key.set("date","20101010");
-    key.set("time","0000");
-    key.set("domain","g");
-    key.set("levtype","sfc");
-    key.set("step","60");
-    key.set("param","130");
-    fdb.archive(key, static_cast<const void *>(data_str.c_str()), data_str.size());
+    key.set("class", "od");
+    key.set("expver", "0001");
+    key.set("type", "fc");
+    key.set("stream", "oper");
+    key.set("date", "20101010");
+    key.set("time", "0000");
+    key.set("domain", "g");
+    key.set("levtype", "sfc");
+    key.set("step", "60");
+    key.set("param", "130");
+    fdb.archive(key, static_cast<const void*>(data_str.c_str()), data_str.size());
     fdb.flush();
 
     metkit::mars::MarsRequest req = key.request();
@@ -139,9 +131,9 @@ CASE ( "test_fdb_stepunit_archive" ) {
         EXPECT(!iter.next(el));
     }
 
-    key.set("step","2");
-    key.set("stepunits","h");
-    fdb.archive(key, static_cast<const void *>(data_str.c_str()), data_str.size());
+    key.set("step", "2");
+    key.set("stepunits", "h");
+    fdb.archive(key, static_cast<const void*>(data_str.c_str()), data_str.size());
     fdb.flush();
 
     req.setValue("step", "2");
@@ -154,7 +146,7 @@ CASE ( "test_fdb_stepunit_archive" ) {
         EXPECT(!iter.next(el));
     }
 
-    req.setValuesTyped(new metkit::mars::TypeAny("step"), std::vector<std::string>{"2","60"});
+    req.setValuesTyped(new metkit::mars::TypeAny("step"), std::vector<std::string>{"2", "60"});
     {
         fdb5::FDBToolRequest r(req);
         fdb5::ListIterator iter = fdb.list(r, true);
@@ -166,9 +158,9 @@ CASE ( "test_fdb_stepunit_archive" ) {
         EXPECT(!iter.next(el));
     }
 
-    key.set("step","30");
-    key.set("stepunits","m");
-    fdb.archive(key, static_cast<const void *>(data_str.c_str()), data_str.size());
+    key.set("step", "30");
+    key.set("stepunits", "m");
+    fdb.archive(key, static_cast<const void*>(data_str.c_str()), data_str.size());
     fdb.flush();
 
     req.setValue("step", "30m");
@@ -181,7 +173,7 @@ CASE ( "test_fdb_stepunit_archive" ) {
         EXPECT(!iter.next(el));
     }
 
-    req.values("step", {"0","to","2","by","30m"});
+    req.values("step", {"0", "to", "2", "by", "30m"});
     req.unsetValues("param");
     {
         metkit::mars::MarsExpension expand{false};
@@ -198,13 +190,12 @@ CASE ( "test_fdb_stepunit_archive" ) {
     }
 }
 
-CASE ( "test_fdb_service" ) {
+CASE("test_fdb_service") {
 
     SETUP("Fixture") {
         FixtureService f;
 
-        SECTION( "test_fdb_service_write" )
-        {
+        SECTION("test_fdb_service_write") {
             fdb5::Archiver fdb;
 
             f.p["class"]  = "rd";
@@ -238,45 +229,39 @@ CASE ( "test_fdb_service" ) {
         }
 
 
-        SECTION( "test_fdb_service_readtobuffer" )
-        {
+        SECTION("test_fdb_service_readtobuffer") {
             fdb5::FDB retriever;
 
             Buffer buffer(1024);
 
-            Translator<size_t,std::string> str;
+            Translator<size_t, std::string> str;
             std::vector<std::string>::iterator param = f.modelParams_.begin();
-            for( ; param != f.modelParams_.end(); ++param )
-            {
-                f.p["param"] = *param;
+            for (; param != f.modelParams_.end(); ++param) {
+                f.p["param"]   = *param;
                 f.p["levtype"] = "pl";
 
-                for( size_t step = 0; step < 2; ++step )
-                {
-                    f.p["step"] = str(step*3);
+                for (size_t step = 0; step < 2; ++step) {
+                    f.p["step"] = str(step * 3);
 
-                    for( size_t level = 0; level < 3; ++level )
-                    {
-                        f.p["levelist"] = str(level*100);
+                    for (size_t level = 0; level < 3; ++level) {
+                        f.p["levelist"] = str(level * 100);
 
                         Log::info() << "Looking for: " << f.p << std::endl;
 
                         metkit::mars::MarsRequest r("retrieve", f.p);
-                        std::unique_ptr<DataHandle> dh ( retriever.retrieve(r) );  AutoClose closer1(*dh);
+                        std::unique_ptr<DataHandle> dh(retriever.retrieve(r));
+                        AutoClose closer1(*dh);
 
                         ::memset(buffer, 0, buffer.size());
 
                         dh->openForRead();
                         dh->read(buffer, buffer.size());
 
-                        Log::info() << (char*) buffer << std::endl;
+                        Log::info() << (char*)buffer << std::endl;
 
                         std::ostringstream data;
                         data << "Raining cats and dogs -- "
-                                << " param " << *param
-                                << " step "  << step
-                                << " level " << level
-                                << std::endl;
+                             << " param " << *param << " step " << step << " level " << level << std::endl;
 
                         EXPECT(::memcmp(buffer, data.str().c_str(), data.str().size()) == 0);
                     }
@@ -285,17 +270,15 @@ CASE ( "test_fdb_service" ) {
         }
 
 
-        SECTION( "test_fdb_service_list" )
-        {
+        SECTION("test_fdb_service_list") {
             fdb5::FDB lister;
 
-            Translator<size_t,std::string> str;
+            Translator<size_t, std::string> str;
             std::vector<std::string>::iterator param = f.modelParams_.begin();
-            for( ; param != f.modelParams_.end(); ++param )
-            {
-                f.p["param"] = *param;
-                f.p["levtype"] = "pl";
-                f.p["step"] = str(0);
+            for (; param != f.modelParams_.end(); ++param) {
+                f.p["param"]    = *param;
+                f.p["levtype"]  = "pl";
+                f.p["step"]     = str(0);
                 f.p["levelist"] = str(0);
 
                 Log::info() << "Looking for: " << f.p << std::endl;
@@ -311,44 +294,44 @@ CASE ( "test_fdb_service" ) {
                 DIR* dirp = ::opendir(path.asString().c_str());
                 struct dirent* dp;
                 while ((dp = ::readdir(dirp)) != nullptr) {
-                    EXPECT_NOT(strstr( dp->d_name, "toc."));
+                    EXPECT_NOT(strstr(dp->d_name, "toc."));
                 }
                 ::closedir(dirp);
 
                 // consuming the rest of the queue
-                while (iter.next(el));
+                while (iter.next(el))
+                    ;
             }
         }
 
-        SECTION( "test_fdb_service_marsreques" )
-        {
+        SECTION("test_fdb_service_marsreques") {
             std::vector<string> steps;
-            steps.push_back( "15" );
-            steps.push_back( "18" );
-            steps.push_back( "24" );
+            steps.push_back("15");
+            steps.push_back("18");
+            steps.push_back("24");
 
             std::vector<string> levels;
-            levels.push_back( "100" );
-            levels.push_back( "500" );
+            levels.push_back("100");
+            levels.push_back("500");
 
             std::vector<string> params;
-            params.push_back( "130.128" );
-            params.push_back( "138.128" );
+            params.push_back("130.128");
+            params.push_back("138.128");
 
             std::vector<string> dates;
-            dates.push_back( "20120911" );
-            dates.push_back( "20120912" );
+            dates.push_back("20120911");
+            dates.push_back("20120912");
 
 
             metkit::mars::MarsRequest r("retrieve");
 
-            r.setValue("class","rd");
-            r.setValue("expver","0001");
-            r.setValue("type","fc");
-            r.setValue("stream","oper");
-            r.setValue("time","0000");
-            r.setValue("domain","g");
-            r.setValue("levtype","pl");
+            r.setValue("class", "rd");
+            r.setValue("expver", "0001");
+            r.setValue("type", "fc");
+            r.setValue("stream", "oper");
+            r.setValue("time", "0000");
+            r.setValue("domain", "g");
+            r.setValue("levtype", "pl");
 
             r.setValuesTyped(new metkit::mars::TypeAny("param"), params);
             r.setValuesTyped(new metkit::mars::TypeAny("step"), steps);
@@ -359,9 +342,9 @@ CASE ( "test_fdb_service" ) {
 
             fdb5::FDB retriever;
 
-            std::unique_ptr<DataHandle> dh ( retriever.retrieve(r) );
+            std::unique_ptr<DataHandle> dh(retriever.retrieve(r));
 
-            PathName path ( "data_mars_request.data" );
+            PathName path("data_mars_request.data");
             path.unlink();
 
             dh->saveInto(path);
@@ -370,8 +353,7 @@ CASE ( "test_fdb_service" ) {
 }
 
 
-
-CASE ( "test_fdb_service_subtoc" ) {
+CASE("test_fdb_service_subtoc") {
 
     SETUP("Fixture") {
         FixtureService f;
@@ -383,8 +365,7 @@ CASE ( "test_fdb_service_subtoc" ) {
 
         fdb5::Config config(expanded, userConf);
 
-        SECTION( "test_fdb_service_subtoc_write" )
-        {
+        SECTION("test_fdb_service_subtoc_write") {
             fdb5::Archiver fdb(config);
 
             f.p["class"]  = "rd";
@@ -417,47 +398,41 @@ CASE ( "test_fdb_service_subtoc" ) {
             f.write_cycle(fdb, f.p);
         }
 
-        SECTION( "test_fdb_service_subtoc_readtobuffer" )
-        {
+        SECTION("test_fdb_service_subtoc_readtobuffer") {
             fdb5::FDB retriever;
 
             Buffer buffer(1024);
 
             f.p["expver"] = "0002";
 
-            Translator<size_t,std::string> str;
+            Translator<size_t, std::string> str;
             std::vector<std::string>::iterator param = f.modelParams_.begin();
-            for( ; param != f.modelParams_.end(); ++param )
-            {
-                f.p["param"] = *param;
+            for (; param != f.modelParams_.end(); ++param) {
+                f.p["param"]   = *param;
                 f.p["levtype"] = "pl";
 
-                for( size_t step = 0; step < 2; ++step )
-                {
-                    f.p["step"] = str(step*3);
+                for (size_t step = 0; step < 2; ++step) {
+                    f.p["step"] = str(step * 3);
 
-                    for( size_t level = 0; level < 3; ++level )
-                    {
-                        f.p["levelist"] = str(level*100);
+                    for (size_t level = 0; level < 3; ++level) {
+                        f.p["levelist"] = str(level * 100);
 
                         Log::info() << "Looking for: " << f.p << std::endl;
 
                         metkit::mars::MarsRequest r("retrieve", f.p);
-                        std::unique_ptr<DataHandle> dh ( retriever.retrieve(r) );  AutoClose closer1(*dh);
+                        std::unique_ptr<DataHandle> dh(retriever.retrieve(r));
+                        AutoClose closer1(*dh);
 
                         ::memset(buffer, 0, buffer.size());
 
                         dh->openForRead();
                         dh->read(buffer, buffer.size());
 
-                        Log::info() << (char*) buffer << std::endl;
+                        Log::info() << (char*)buffer << std::endl;
 
                         std::ostringstream data;
                         data << "Raining cats and dogs -- "
-                                << " param " << *param
-                                << " step "  << step
-                                << " level " << level
-                                << std::endl;
+                             << " param " << *param << " step " << step << " level " << level << std::endl;
 
                         EXPECT(::memcmp(buffer, data.str().c_str(), data.str().size()) == 0);
                     }
@@ -466,20 +441,18 @@ CASE ( "test_fdb_service_subtoc" ) {
         }
 
 
-        SECTION( "test_fdb_service_subtoc_list" )
-        {
+        SECTION("test_fdb_service_subtoc_list") {
             fdb5::FDB lister;
 
             f.p["expver"] = "0002";
 
-            Translator<size_t,std::string> str;
+            Translator<size_t, std::string> str;
             std::vector<std::string>::iterator param = f.modelParams_.begin();
-            for( ; param != f.modelParams_.end(); ++param )
-            {
+            for (; param != f.modelParams_.end(); ++param) {
 
-                f.p["param"] = *param;
-                f.p["levtype"] = "pl";
-                f.p["step"] = str(0);
+                f.p["param"]    = *param;
+                f.p["levtype"]  = "pl";
+                f.p["step"]     = str(0);
                 f.p["levelist"] = str(0);
 
                 Log::info() << "Looking for: " << f.p << std::endl;
@@ -496,7 +469,7 @@ CASE ( "test_fdb_service_subtoc" ) {
                 struct dirent* dp;
                 bool subtoc = false;
                 while ((dp = ::readdir(dirp)) != nullptr) {
-                    if (strstr( dp->d_name, "toc.")) {
+                    if (strstr(dp->d_name, "toc.")) {
                         subtoc = true;
                     }
                 }
@@ -504,39 +477,39 @@ CASE ( "test_fdb_service_subtoc" ) {
                 ::closedir(dirp);
 
                 // consuming the rest of the queue
-                while (iter.next(el));
+                while (iter.next(el))
+                    ;
             }
         }
 
-        SECTION( "test_fdb_service_subtoc_marsreques" )
-        {
+        SECTION("test_fdb_service_subtoc_marsreques") {
             std::vector<string> steps;
-            steps.push_back( "15" );
-            steps.push_back( "18" );
-            steps.push_back( "24" );
+            steps.push_back("15");
+            steps.push_back("18");
+            steps.push_back("24");
 
             std::vector<string> levels;
-            levels.push_back( "100" );
-            levels.push_back( "500" );
+            levels.push_back("100");
+            levels.push_back("500");
 
             std::vector<string> params;
-            params.push_back( "130.128" );
-            params.push_back( "138.128" );
+            params.push_back("130.128");
+            params.push_back("138.128");
 
             std::vector<string> dates;
-            dates.push_back( "20120911" );
-            dates.push_back( "20120912" );
+            dates.push_back("20120911");
+            dates.push_back("20120912");
 
 
             metkit::mars::MarsRequest r("retrieve");
 
-            r.setValue("class","rd");
-            r.setValue("expver","0002");
-            r.setValue("type","fc");
-            r.setValue("stream","oper");
-            r.setValue("time","0000");
-            r.setValue("domain","g");
-            r.setValue("levtype","pl");
+            r.setValue("class", "rd");
+            r.setValue("expver", "0002");
+            r.setValue("type", "fc");
+            r.setValue("stream", "oper");
+            r.setValue("time", "0000");
+            r.setValue("domain", "g");
+            r.setValue("levtype", "pl");
 
             r.setValuesTyped(new metkit::mars::TypeAny("param"), params);
             r.setValuesTyped(new metkit::mars::TypeAny("step"), steps);
@@ -547,9 +520,9 @@ CASE ( "test_fdb_service_subtoc" ) {
 
             fdb5::FDB retriever;
 
-            std::unique_ptr<DataHandle> dh ( retriever.retrieve(r) );
+            std::unique_ptr<DataHandle> dh(retriever.retrieve(r));
 
-            PathName path ( "data_mars_request.data" );
+            PathName path("data_mars_request.data");
             path.unlink();
 
             dh->saveInto(path);
@@ -557,7 +530,7 @@ CASE ( "test_fdb_service_subtoc" ) {
     }
 }
 
-CASE( "schemaSerialisation" ) {
+CASE("schemaSerialisation") {
 
     PathName filename    = PathName::unique("data");
     std::string filepath = filename.asString();
@@ -598,8 +571,7 @@ CASE( "schemaSerialisation" ) {
 }  // namespace test
 }  // namespace fdb
 
-int main(int argc, char **argv)
-{
+int main(int argc, char** argv) {
     eckit::Main::initialise(argc, argv, "FDB_HOME");
-    return run_tests ( argc, argv, false );
+    return run_tests(argc, argv, false);
 }
