@@ -15,33 +15,33 @@
 #include "eckit/option/CmdArgs.h"
 #include "eckit/option/SimpleOption.h"
 
-#include "metkit/mars/MarsRequest.h"
-#include "metkit/mars/MarsParser.h"
 #include "metkit/mars/MarsExpension.h"
+#include "metkit/mars/MarsParser.h"
+#include "metkit/mars/MarsRequest.h"
 
 #include "fdb5/LibFdb5.h"
 #include "fdb5/api/FDB.h"
-#include "fdb5/message/MessageDecoder.h"
 #include "fdb5/io/HandleGatherer.h"
+#include "fdb5/message/MessageDecoder.h"
 #include "fdb5/tools/FDBTool.h"
 
 
 class FDBUrl : public fdb5::FDBTool {
-    virtual void execute(const eckit::option::CmdArgs &args);
-    virtual void usage(const std::string &tool) const;
+    virtual void execute(const eckit::option::CmdArgs& args);
+    virtual void usage(const std::string& tool) const;
     virtual int numberOfPositionalArguments() const { return 2; }
-  public:
-    FDBUrl(int argc, char **argv): fdb5::FDBTool(argc, argv) {
+
+public:
+
+    FDBUrl(int argc, char** argv) : fdb5::FDBTool(argc, argv) {
         options_.push_back(new eckit::option::SimpleOption<bool>("uri", "Inspect -> URI -> Read"));
         options_.push_back(new eckit::option::SimpleOption<bool>("extract", "Extract request from a GRIB file"));
         options_.push_back(new eckit::option::SimpleOption<bool>("raw", "Uses the raw request, without expansion"));
-        options_.push_back(
-                    new eckit::option::SimpleOption<bool>("statistics",
-                                                          "Report timing statistics"));
+        options_.push_back(new eckit::option::SimpleOption<bool>("statistics", "Report timing statistics"));
     }
 };
 
-void FDBUrl::usage(const std::string &tool) const {
+void FDBUrl::usage(const std::string& tool) const {
     eckit::Log::info() << std::endl
                        << "Usage: " << tool << " request.mars target.grib" << std::endl
                        << "       " << tool << " --raw request.mars target.grib" << std::endl
@@ -51,11 +51,11 @@ void FDBUrl::usage(const std::string &tool) const {
     fdb5::FDBTool::usage(tool);
 }
 
-void FDBUrl::execute(const eckit::option::CmdArgs &args) {
+void FDBUrl::execute(const eckit::option::CmdArgs& args) {
 
     bool extract = args.getBool("extract", false);
-    bool raw = args.getBool("raw", false);
-    bool uri = args.getBool("uri", false);
+    bool raw     = args.getBool("raw", false);
+    bool uri     = args.getBool("uri", false);
 
     std::vector<metkit::mars::MarsRequest> requests;
 
@@ -67,8 +67,8 @@ void FDBUrl::execute(const eckit::option::CmdArgs &args) {
 
         fdb5::MessageDecoder decoder;
         requests = decoder.messageToRequests(args(0));
-
-    } else {
+    }
+    else {
         std::ifstream in(args(0).c_str());
         if (in.bad()) {
             throw eckit::ReadError(args(0));
@@ -79,7 +79,8 @@ void FDBUrl::execute(const eckit::option::CmdArgs &args) {
         if (raw) {
             for (auto r : parsedRequests)
                 requests.push_back(r);
-        } else {
+        }
+        else {
             metkit::mars::MarsExpension expand(/* inherit */ false);
             requests = expand.expand(parsedRequests);
         }
@@ -109,7 +110,8 @@ void FDBUrl::execute(const eckit::option::CmdArgs &args) {
                 eckit::URI newUri(uriStr);
                 handles.add(fdb.read(newUri));
             }
-        } else {
+        }
+        else {
             handles.add(fdb.retrieve(request));
         }
     }
@@ -121,8 +123,7 @@ void FDBUrl::execute(const eckit::option::CmdArgs &args) {
 }
 
 
-int main(int argc, char **argv) {
+int main(int argc, char** argv) {
     FDBUrl app(argc, argv);
     return app.start();
 }
-
